.gu-mirror {
  position: fixed !important;
  margin: 0 !important;
  z-index: 9999 !important;
  opacity: .8;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
  filter: alpha(opacity=80); }

.gu-hide {
  display: none !important; }

.gu-unselectable {
  -webkit-user-select: none !important;
  -moz-user-select: none !important;
  -ms-user-select: none !important;
  user-select: none !important; }

.gu-transit {
  opacity: .2;
  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=20)";
  filter: alpha(opacity=20); }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .checklist-wrapper .toggle-completed, li.checklist-item .line-item .item-title input.readonly[type="text"], .new-item .line-item .item-title input.readonly[type="text"], li.checklist-item .item-tools, .new-item .item-tools {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

.checklist-wrapper {
  width: 100%;
  padding: 15px; }
  .checklist-wrapper .toggle-completed {
    display: inline-block;
    color: #0079bf;
    cursor: pointer;
    padding: 10px 0; }
    .checklist-wrapper .toggle-completed:hover {
      font-weight: bold; }
  .checklist-wrapper .new-item {
    color: white;
    cursor: pointer;
    margin-bottom: 15px;
    border: none;
    background-color: #27ae60; }
    .checklist-wrapper .new-item:hover {
      background-color: #2ecc71; }
    .checklist-wrapper .new-item .line-item .new-item-button {
      float: left;
      height: 30px;
      width: 30px;
      font-size: 22px;
      text-align: center;
      margin-left: 2px; }
    .checklist-wrapper .new-item .line-item .new-item-text {
      height: 30px;
      margin-left: 3px;
      margin-top: 5px; }
    .checklist-wrapper .new-item:hover {
      text-decoration: underline; }
  .checklist-wrapper ul.checklist {
    list-style: none;
    padding: 0;
    margin: 0; }

li.checklist-item, .new-item {
  list-style: none;
  background-color: white;
  position: relative;
  margin-bottom: 0;
  border: 1px solid #ccc;
  box-shadow: none;
  padding: 7px;
  height: auto;
  margin-top: -1px;
  opacity: 1;
  -webkit-transition: all 1s;
  -ms-transition: all 1s;
  -moz-transition: all 1s;
  -o-transition: all 1s;
  transition: all 1s; }
  li.checklist-item.item-hidden, .new-item.item-hidden {
    -webkit-transition: all 1s;
    -ms-transition: all 1s;
    -moz-transition: all 1s;
    -o-transition: all 1s;
    transition: all 1s;
    height: 0;
    padding: 0;
    margin-top: 0;
    opacity: 0;
    border: 0; }
    li.checklist-item.item-hidden.item-expanded, .new-item.item-hidden.item-expanded {
      margin: 0; }
  li.checklist-item.item-expanded, .new-item.item-expanded {
    -webkit-transition: all 0.5s;
    -ms-transition: all 0.5s;
    -moz-transition: all 0.5s;
    -o-transition: all 0.5s;
    transition: all 0.5s;
    margin-top: 5px;
    margin-bottom: 20px; }
  li.checklist-item .item-description, .new-item .item-description {
    -webkit-transition: all 0.5s;
    -ms-transition: all 0.5s;
    -moz-transition: all 0.5s;
    -o-transition: all 0.5s;
    transition: all 0.5s;
    opacity: 0;
    height: 0;
    margin-bottom: 0;
    margin-left: 30px;
    margin-right: 75px;
    overflow: hidden; }
    li.checklist-item .item-description.expanded, .new-item .item-description.expanded {
      -webkit-transition: all 0.5s;
      -ms-transition: all 0.5s;
      -moz-transition: all 0.5s;
      -o-transition: all 0.5s;
      transition: all 0.5s;
      opacity: 1;
      height: auto;
      min-height: 100px;
      margin-top: 10px;
      margin-bottom: 10px;
      padding-left: 10px; }
      li.checklist-item .item-description.expanded .comment, .new-item .item-description.expanded .comment {
        position: relative;
        margin-top: -1px; }
        li.checklist-item .item-description.expanded .comment:first-child, .new-item .item-description.expanded .comment:first-child {
          margin-top: 0; }
        li.checklist-item .item-description.expanded .comment:last-child, .new-item .item-description.expanded .comment:last-child {
          margin-top: 10px; }
        li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper, .new-item .item-description.expanded .comment .orchestra-quill-wrapper {
          box-shadow: none;
          border: 1px solid #ccc; }
          li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-editor, .new-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-editor {
            min-height: 150px;
            height: auto; }
          li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper.readonly .orchestra-quill-editor, .new-item .item-description.expanded .comment .orchestra-quill-wrapper.readonly .orchestra-quill-editor {
            min-height: 0;
            margin-top: 15px; }
          li.checklist-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-toolbar, .new-item .item-description.expanded .comment .orchestra-quill-wrapper .orchestra-quill-toolbar {
            margin-top: 0;
            border-top: none; }
        li.checklist-item .item-description.expanded .comment .comment-meta, .new-item .item-description.expanded .comment .comment-meta {
          font-size: 10px;
          position: absolute;
          top: 15px;
          left: 15px;
          right: 15px; }
          li.checklist-item .item-description.expanded .comment .comment-meta .comment-author, .new-item .item-description.expanded .comment .comment-meta .comment-author {
            float: left; }
          li.checklist-item .item-description.expanded .comment .comment-meta .comment-timestamp, .new-item .item-description.expanded .comment .comment-meta .comment-timestamp {
            float: right; }
        li.checklist-item .item-description.expanded .comment .add-comment, .new-item .item-description.expanded .comment .add-comment {
          color: #27ae60; }
  li.checklist-item .line-item, .new-item .line-item {
    overflow: hidden;
    position: relative;
    height: 30px;
    width: 100%;
    cursor: pointer; }
    li.checklist-item .line-item .item-title, .new-item .line-item .item-title {
      position: absolute;
      top: 0;
      bottom: 0;
      left: 30px;
      right: 75px;
      padding: 0 10px; }
      li.checklist-item .line-item .item-title input[type="text"], .new-item .line-item .item-title input[type="text"] {
        box-sizing: content-box;
        max-width: 100%;
        height: 26px;
        outline: none;
        border: 1px solid #0079bf;
        -webkit-transition: border 0.5s;
        -ms-transition: border 0.5s;
        -moz-transition: border 0.5s;
        -o-transition: border 0.5s;
        transition: border 0.5s; }
        li.checklist-item .line-item .item-title input[type="text"].readonly, .new-item .line-item .item-title input[type="text"].readonly {
          cursor: text;
          border: 1px solid white; }
    li.checklist-item .line-item input[type="checkbox"], .new-item .line-item input[type="checkbox"] {
      display: none; }
    li.checklist-item .line-item label, .new-item .line-item label {
      -webkit-transition: all 0.5s;
      -ms-transition: all 0.5s;
      -moz-transition: all 0.5s;
      -o-transition: all 0.5s;
      transition: all 0.5s;
      position: absolute;
      top: 0;
      left: 0;
      height: 30px;
      width: 30px;
      margin: 0;
      color: white;
      cursor: pointer;
      border: 1px solid #0079bf;
      box-shadow: inset 0 0 1px #0079bf; }
      li.checklist-item .line-item label.checked, .new-item .line-item label.checked {
        -webkit-transition: all 0.5s;
        -ms-transition: all 0.5s;
        -moz-transition: all 0.5s;
        -o-transition: all 0.5s;
        transition: all 0.5s;
        background-color: #0079bf; }
      li.checklist-item .line-item label i, .new-item .line-item label i {
        -webkit-transition: all 0.5s;
        -ms-transition: all 0.5s;
        -moz-transition: all 0.5s;
        -o-transition: all 0.5s;
        transition: all 0.5s;
        visibility: hidden; }
      li.checklist-item .line-item label.checked i, .new-item .line-item label.checked i {
        -webkit-transition: all 0.5s;
        -ms-transition: all 0.5s;
        -moz-transition: all 0.5s;
        -o-transition: all 0.5s;
        transition: all 0.5s;
        visibility: visible; }
      li.checklist-item .line-item label i, .new-item .line-item label i {
        font-size: 22px;
        position: absolute;
        top: 3px;
        left: 3px; }
  li.checklist-item .item-tools, .new-item .item-tools {
    position: absolute;
    right: 75px; }
    li.checklist-item .item-tools .tool, li.checklist-item .item-tools .expand-toggle, li.checklist-item .item-tools .edit-toggle, li.checklist-item .item-tools .item-remove, .new-item .item-tools .tool, .new-item li.checklist-item .item-tools .expand-toggle, li.checklist-item .new-item .item-tools .expand-toggle, .new-item .item-tools .expand-toggle, .new-item li.checklist-item .item-tools .edit-toggle, li.checklist-item .new-item .item-tools .edit-toggle, .new-item .item-tools .edit-toggle, .new-item li.checklist-item .item-tools .item-remove, li.checklist-item .new-item .item-tools .item-remove, .new-item .item-tools .item-remove {
      width: 25px;
      text-align: center;
      position: absolute;
      top: 5px; }
    li.checklist-item .item-tools .expand-toggle, .new-item .item-tools .expand-toggle {
      left: 0;
      cursor: pointer; }
      li.checklist-item .item-tools .expand-toggle.selected, .new-item .item-tools .expand-toggle.selected {
        color: #0079bf; }
    li.checklist-item .item-tools .edit-toggle, .new-item .item-tools .edit-toggle {
      left: 25px;
      cursor: pointer; }
      li.checklist-item .item-tools .edit-toggle.selected, .new-item .item-tools .edit-toggle.selected {
        color: #0079bf; }
    li.checklist-item .item-tools .item-remove, .new-item .item-tools .item-remove {
      left: 50px;
      cursor: pointer;
      color: red; }
/*! Quill Editor v0.20.1
 *  https://quilljs.com/
 *  Copyright (c) 2014, Jason Chen
 *  Copyright (c) 2013, salesforce.com
 */
.ql-image-tooltip {
  padding: 10px;
  width: 300px; }

.ql-image-tooltip:after {
  clear: both;
  content: "";
  display: table; }

.ql-image-tooltip a {
  border: 1px solid #000;
  box-sizing: border-box;
  display: inline-block;
  float: left;
  padding: 5px;
  text-align: center;
  width: 50%; }

.ql-image-tooltip img {
  bottom: 0;
  left: 0;
  margin: auto;
  max-height: 100%;
  max-width: 100%;
  position: absolute;
  right: 0;
  top: 0; }

.ql-image-tooltip .input {
  box-sizing: border-box;
  width: 100%; }

.ql-image-tooltip .preview {
  margin: 10px 0px;
  position: relative;
  border: 1px dashed #000;
  height: 200px; }

.ql-image-tooltip .preview span {
  display: inline-block;
  position: absolute;
  text-align: center;
  top: 40%;
  width: 100%; }

.ql-link-tooltip {
  padding: 5px 10px; }

.ql-link-tooltip input.input {
  width: 170px; }

.ql-link-tooltip input.input,
.ql-link-tooltip a.done {
  display: none; }

.ql-link-tooltip a.change {
  margin-right: 4px; }

.ql-link-tooltip.editing input.input,
.ql-link-tooltip.editing a.done {
  display: inline-block; }

.ql-link-tooltip.editing a.url,
.ql-link-tooltip.editing a.change,
.ql-link-tooltip.editing a.remove {
  display: none; }

.ql-multi-cursor {
  position: absolute;
  left: 0;
  top: 0;
  z-index: 1000; }

.ql-multi-cursor .cursor {
  margin-left: -1px;
  position: absolute; }

.ql-multi-cursor .cursor-flag {
  bottom: 100%;
  position: absolute;
  white-space: nowrap; }

.ql-multi-cursor .cursor-name {
  display: inline-block;
  color: #fff;
  padding: 2px 8px; }

.ql-multi-cursor .cursor-caret {
  height: 100%;
  position: absolute;
  width: 2px; }

.ql-multi-cursor .cursor.hidden .cursor-flag {
  display: none; }

.ql-multi-cursor .cursor.top .cursor-flag {
  bottom: auto;
  top: 100%; }

.ql-multi-cursor .cursor.right .cursor-flag {
  right: -2px; }

.ql-paste-manager {
  left: -100000px;
  position: absolute;
  top: 50%; }

.ql-toolbar {
  box-sizing: border-box; }

.ql-tooltip {
  background-color: #fff;
  border: 1px solid #000;
  box-sizing: border-box;
  position: absolute;
  top: 0px;
  white-space: nowrap;
  z-index: 2000; }

.ql-tooltip a {
  cursor: pointer;
  text-decoration: none; }

.ql-container {
  box-sizing: border-box;
  cursor: text;
  font-family: Helvetica, 'Arial', sans-serif;
  font-size: 13px;
  height: 100%;
  line-height: 1.42;
  margin: 0px;
  overflow-x: hidden;
  overflow-y: auto;
  padding: 12px 15px;
  position: relative; }

.ql-editor {
  box-sizing: border-box;
  min-height: 100%;
  outline: none;
  tab-size: 4;
  white-space: pre-wrap; }

.ql-editor div {
  margin: 0;
  padding: 0; }

.ql-editor a {
  text-decoration: underline; }

.ql-editor b {
  font-weight: bold; }

.ql-editor i {
  font-style: italic; }

.ql-editor s {
  text-decoration: line-through; }

.ql-editor u {
  text-decoration: underline; }

.ql-editor a,
.ql-editor b,
.ql-editor i,
.ql-editor s,
.ql-editor u,
.ql-editor span {
  background-color: inherit; }

.ql-editor img {
  max-width: 100%; }

.ql-editor blockquote,
.ql-editor ol,
.ql-editor ul {
  margin: 0 0 0 2em;
  padding: 0; }

.ql-editor ol {
  list-style-type: decimal; }

.ql-editor ul {
  list-style-type: disc; }

.ql-editor.ql-ie-9 br,
.ql-editor.ql-ie-10 br {
  display: none; }
/*! Quill Editor v0.20.1
 *  https://quilljs.com/
 *  Copyright (c) 2014, Jason Chen
 *  Copyright (c) 2013, salesforce.com
 */
.ql-image-tooltip {
  padding: 10px;
  width: 300px; }

.ql-image-tooltip:after {
  clear: both;
  content: "";
  display: table; }

.ql-image-tooltip a {
  border: 1px solid #000;
  box-sizing: border-box;
  display: inline-block;
  float: left;
  padding: 5px;
  text-align: center;
  width: 50%; }

.ql-image-tooltip img {
  bottom: 0;
  left: 0;
  margin: auto;
  max-height: 100%;
  max-width: 100%;
  position: absolute;
  right: 0;
  top: 0; }

.ql-image-tooltip .input {
  box-sizing: border-box;
  width: 100%; }

.ql-image-tooltip .preview {
  margin: 10px 0px;
  position: relative;
  border: 1px dashed #000;
  height: 200px; }

.ql-image-tooltip .preview span {
  display: inline-block;
  position: absolute;
  text-align: center;
  top: 40%;
  width: 100%; }

.ql-link-tooltip {
  padding: 5px 10px; }

.ql-link-tooltip input.input {
  width: 170px; }

.ql-link-tooltip input.input,
.ql-link-tooltip a.done {
  display: none; }

.ql-link-tooltip a.change {
  margin-right: 4px; }

.ql-link-tooltip.editing input.input,
.ql-link-tooltip.editing a.done {
  display: inline-block; }

.ql-link-tooltip.editing a.url,
.ql-link-tooltip.editing a.change,
.ql-link-tooltip.editing a.remove {
  display: none; }

.ql-multi-cursor {
  position: absolute;
  left: 0;
  top: 0;
  z-index: 1000; }

.ql-multi-cursor .cursor {
  margin-left: -1px;
  position: absolute; }

.ql-multi-cursor .cursor-flag {
  bottom: 100%;
  position: absolute;
  white-space: nowrap; }

.ql-multi-cursor .cursor-name {
  display: inline-block;
  color: #fff;
  padding: 2px 8px; }

.ql-multi-cursor .cursor-caret {
  height: 100%;
  position: absolute;
  width: 2px; }

.ql-multi-cursor .cursor.hidden .cursor-flag {
  display: none; }

.ql-multi-cursor .cursor.top .cursor-flag {
  bottom: auto;
  top: 100%; }

.ql-multi-cursor .cursor.right .cursor-flag {
  right: -2px; }

.ql-paste-manager {
  left: -100000px;
  position: absolute;
  top: 50%; }

.ql-toolbar {
  box-sizing: border-box; }

.ql-tooltip {
  background-color: #fff;
  border: 1px solid #000;
  box-sizing: border-box;
  position: absolute;
  top: 0px;
  white-space: nowrap;
  z-index: 2000; }

.ql-tooltip a {
  cursor: pointer;
  text-decoration: none; }

.ql-container {
  box-sizing: border-box;
  cursor: text;
  font-family: Helvetica, 'Arial', sans-serif;
  font-size: 13px;
  height: 100%;
  line-height: 1.42;
  margin: 0px;
  overflow-x: hidden;
  overflow-y: auto;
  padding: 12px 15px;
  position: relative; }

.ql-editor {
  box-sizing: border-box;
  min-height: 100%;
  outline: none;
  tab-size: 4;
  white-space: pre-wrap; }

.ql-editor div {
  margin: 0;
  padding: 0; }

.ql-editor a {
  text-decoration: underline; }

.ql-editor b {
  font-weight: bold; }

.ql-editor i {
  font-style: italic; }

.ql-editor s {
  text-decoration: line-through; }

.ql-editor u {
  text-decoration: underline; }

.ql-editor a,
.ql-editor b,
.ql-editor i,
.ql-editor s,
.ql-editor u,
.ql-editor span {
  background-color: inherit; }

.ql-editor img {
  max-width: 100%; }

.ql-editor blockquote,
.ql-editor ol,
.ql-editor ul {
  margin: 0 0 0 2em;
  padding: 0; }

.ql-editor ol {
  list-style-type: decimal; }

.ql-editor ul {
  list-style-type: disc; }

.ql-editor.ql-ie-9 br,
.ql-editor.ql-ie-10 br {
  display: none; }

.ql-snow .ql-image-tooltip a {
  border: 1px solid #06c; }

.ql-snow .ql-image-tooltip a.insert {
  background-color: #06c;
  color: #fff; }

.ql-snow .ql-image-tooltip .preview {
  border-color: #ccc;
  color: #ccc; }

.ql-snow .ql-link-tooltip a,
.ql-snow .ql-link-tooltip span {
  line-height: 25px; }

.ql-snow .ql-multi-cursor .cursor-name {
  border-radius: 4px;
  font-size: 11px;
  font-family: Arial;
  margin-left: -50%;
  padding: 4px 10px; }

.ql-snow .ql-multi-cursor .cursor-triangle {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  height: 0px;
  margin-left: -3px;
  width: 0px; }

.ql-snow .ql-multi-cursor .cursor.left .cursor-name {
  margin-left: -8px; }

.ql-snow .ql-multi-cursor .cursor.right .cursor-flag {
  right: auto; }

.ql-snow .ql-multi-cursor .cursor.right .cursor-name {
  margin-left: -100%;
  margin-right: -8px; }

.ql-snow .ql-multi-cursor .cursor-triangle.bottom {
  border-top: 4px solid transparent;
  display: block;
  margin-bottom: -1px; }

.ql-snow .ql-multi-cursor .cursor-triangle.top {
  border-bottom: 4px solid transparent;
  display: none;
  margin-top: -1px; }

.ql-snow .ql-multi-cursor .cursor.top .cursor-triangle.bottom {
  display: none; }

.ql-snow .ql-multi-cursor .cursor.top .cursor-triangle.top {
  display: block; }

.ql-snow.ql-toolbar {
  box-sizing: border-box;
  padding: 8px;
  user-select: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none; }

.ql-snow.ql-toolbar .ql-format-group {
  display: inline-block;
  margin-right: 15px;
  vertical-align: middle; }

.ql-snow.ql-toolbar .ql-format-separator {
  box-sizing: border-box;
  background-color: #ddd;
  display: inline-block;
  height: 14px;
  margin-left: 4px;
  margin-right: 4px;
  vertical-align: middle;
  width: 1px; }

.ql-snow.ql-toolbar .ql-format-button {
  box-sizing: border-box;
  display: inline-block;
  height: 24px;
  line-height: 24px;
  vertical-align: middle;
  background-position: center center;
  background-repeat: no-repeat;
  background-size: 18px 18px;
  box-sizing: border-box;
  cursor: pointer;
  text-align: center;
  width: 24px; }

.ql-snow.ql-toolbar .ql-picker {
  box-sizing: border-box;
  color: #444;
  display: inline-block;
  font-family: 'Helvetica Neue', 'Helvetica', 'Arial', sans-serif;
  font-size: 14px;
  font-weight: 500;
  position: relative; }

.ql-snow.ql-toolbar .ql-picker .ql-picker-label {
  box-sizing: border-box;
  display: inline-block;
  height: 24px;
  line-height: 24px;
  vertical-align: middle;
  background-color: #fff;
  background-position: right center;
  background-repeat: no-repeat;
  background-size: 18px 18px;
  border: 1px solid transparent;
  cursor: pointer;
  position: relative;
  width: 100%; }

.ql-snow.ql-toolbar .ql-picker .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label:hover {
  color: #06c; }

.ql-snow.ql-toolbar .ql-picker .ql-picker-options {
  background-color: #fff;
  border: 1px solid transparent;
  box-sizing: border-box;
  display: none;
  padding: 4px 8px;
  position: absolute;
  width: 100%; }

.ql-snow.ql-toolbar .ql-picker .ql-picker-options .ql-picker-item {
  background-position: center center;
  background-repeat: no-repeat;
  background-size: 18px 18px;
  box-sizing: border-box;
  cursor: pointer;
  display: block;
  padding-bottom: 5px;
  padding-top: 5px; }

.ql-snow.ql-toolbar .ql-picker .ql-picker-options .ql-picker-item.ql-selected,
.ql-snow.ql-toolbar .ql-picker .ql-picker-options .ql-picker-item:hover {
  color: #06c; }

.ql-snow.ql-toolbar .ql-picker.ql-expanded .ql-picker-label {
  border-color: #ccc;
  color: #ccc;
  z-index: 2; }

.ql-snow.ql-toolbar .ql-picker.ql-expanded .ql-picker-options {
  border-color: #ccc;
  box-shadow: rgba(0, 0, 0, 0.2) 0 2px 8px;
  display: block;
  margin-top: -1px;
  z-index: 1; }

.ql-snow.ql-toolbar .ql-picker.ql-color-picker .ql-picker-label {
  background-position: center center;
  width: 28px; }

.ql-snow.ql-toolbar .ql-picker.ql-color-picker .ql-picker-options {
  padding: 5px;
  width: 152px; }

.ql-snow.ql-toolbar .ql-picker.ql-color-picker .ql-picker-options .ql-picker-item {
  border: 1px solid transparent;
  float: left;
  height: 16px;
  margin: 2px;
  padding: 0px;
  width: 16px; }

.ql-snow.ql-toolbar .ql-picker.ql-color-picker .ql-picker-options .ql-picker-item.ql-primary-color {
  margin-bottom: 8px; }

.ql-snow.ql-toolbar .ql-picker.ql-color-picker .ql-picker-options .ql-picker-item.ql-selected,
.ql-snow.ql-toolbar .ql-picker.ql-color-picker .ql-picker-options .ql-picker-item:hover {
  border-color: #000; }

.ql-snow.ql-toolbar .ql-picker.ql-font {
  width: 105px; }

.ql-snow.ql-toolbar .ql-picker.ql-size {
  width: 80px; }

.ql-snow.ql-toolbar .ql-picker.ql-font .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker.ql-size .ql-picker-label {
  padding-left: 8px;
  padding-right: 8px; }

.ql-snow.ql-toolbar .ql-picker.ql-align .ql-picker-label {
  background-position: center center;
  width: 28px; }

.ql-snow.ql-toolbar .ql-picker.ql-align .ql-picker-item {
  box-sizing: border-box;
  display: inline-block;
  height: 24px;
  line-height: 24px;
  vertical-align: middle;
  padding: 0px;
  width: 28px; }

.ql-snow.ql-toolbar .ql-picker.ql-align .ql-picker-options {
  padding: 4px 0px; }

.ql-snow.ql-toolbar .ql-picker .ql-picker-label {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAKlBMVEUAAABJSUlAQEBERERFRUVERERERERERERERERFRUVEREREREREREREREQJcW6NAAAADXRSTlMAFRzExcbLzM/Q0dLbKbcyLwAAADVJREFUCNdjYCAeMKYJQFnSdzdCWbl3r0NZvnev4tFre/cKlNV79yaUpXP3EJTFtEqBBHcAAHyoDQk0vM/lAAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-picker.ql-expanded .ql-picker-label {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAYAAABWzo5XAAAAdElEQVR42mP4//8/VfBINGjVqlUMhw4dEj148OBpEAaxQWKkGgQz5BIQ/4fiSyAxkg2CuuQ/Gj5DjkFHsRh0jJwwwooHzCCQ145g8dpRcgw6j8WgCyQbtH//fhmgxttIhtwGiZETRjDDLoIwiA0UG820FGAA5b25+qRqGXcAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-picker.ql-active:not(.ql-expanded) .ql-picker-label,
.ql-snow.ql-toolbar:not(.ios) .ql-picker:not(.ql-expanded) .ql-picker-label:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAKlBMVEUAAAAAYc4AZMgAZcwAZs0AZs0AZs0AZ8wAZswAZs0AZswAZswAZswAZsx12LPhAAAADXRSTlMAFRzExcbLzM/Q0dLbKbcyLwAAADVJREFUCNdjYCAeMKYJQFnSdzdCWbl3r0NZvnev4tFre/cKlNV79yaUpXP3EJTFtEqBBHcAAHyoDQk0vM/lAAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-bold,
.ql-snow.ql-toolbar .ql-picker.ql-bold .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bold],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bold] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAYFBMVEUAAACAgIBAQEA5OTlAQEBERERAQEBERERERERERERDQ0NERERERERERERDQ0NERERERERFRUVERERERERFRUVERERERERERERERERERERERERERERERERERERERERERESN6WzHAAAAH3RSTlMAAggJDA8cQEtTWHF/i4yTpau+xMXX3O7v8/f6+/z+qN9w2AAAAFZJREFUeNqlzMcSgCAMRVEsYO+9vv//S9FhNIYld5HFmSTCqQ66dazkRzA1lPSQGRZGIsDMKMxRW7+2yCIcyf/QUyUGSnc+dkaqoFumM32pf2BqY+HUBfQaCPgVIBc1AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-bold.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-bold .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bold].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bold].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-bold:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-bold .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=bold]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=bold]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAYFBMVEUAAAAAgP8AYL8AccYAatUAZswAZMgAZMsAZswAZcsAZcsAZssAZssAZ80AZswAZs0AZswAZ8wAZswAZcwAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsxCU9XcAAAAH3RSTlMAAggJDA8cQEtTWHF/i4yTpau+xMXX3O7v8/f6+/z+qN9w2AAAAFZJREFUeNqlzMcSgCAMRVEsYO+9vv//S9FhNIYld5HFmSTCqQ66dazkRzA1lPSQGRZGIsDMKMxRW7+2yCIcyf/QUyUGSnc+dkaqoFumM32pf2BqY+HUBfQaCPgVIBc1AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-italic,
.ql-snow.ql-toolbar .ql-picker.ql-italic .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=italic],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=italic] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAYAAABWzo5XAAAAi0lEQVR42mMYvoARl4SLi0sNkGoAYmY0qf+MjIztu3fvrkYWZGLADZhB8pS4CN1lQUBqLRDvAQJXHMqIstEISp8BEZQYZAIi/v//f5ZSg0xBBCMj4ymyDQKGjxKQEgLiV8DweUS2QUBXGEOZp0EEJV4zgdJnKDLo379/JsS6iJHSFA0DTDhT9CiAAQBbWyIY/pd4rQAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-italic.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-italic .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=italic].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=italic].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-italic:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-italic .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=italic]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=italic]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAYAAABWzo5XAAAAk0lEQVR42u3SsQ3CMBBA0X/2BozACMQswg4EMQMUdOyQVdggdpagZAc4ihjJjYmU66K8xpZsfdnSsVxCzTFdEW6AB0oKcqdrLhQcNaK+PLc79QfapLTDgz8cU9Tv8ibZQqIBgI8OxhexH29KPz90jltgA7zownN+6C0Nowhg+JqEvCZbSDSHNDJBLBNdctWJXv18Ad5dJL0jVfDhAAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-underline,
.ql-snow.ql-toolbar .ql-picker.ql-underline .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=underline],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=underline] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAM1BMVEUAAABLS0tFRUVDQ0NERERDQ0NFRUVFRUVERERDQ0NERERFRUVERERERERERERERERERESvCHKbAAAAEHRSTlMAERpMbW6Bgry9xMXh5PP51ZZfkwAAAEdJREFUeNq9yEEKgDAMRNHERDWq6dz/tFLBQUC6KfRtPnzpsh/sC2AHrcRUo0iuDXONI7gMxVW9wIQWPFb5sMgMk5YTdMmvGw2DA8yS9di7AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-underline.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-underline .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=underline].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=underline].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-underline:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-underline .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=underline]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=underline]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAM1BMVEUAAAAAadIAYs4AZc0AZcwAZswAZ84AZswAZs0AZ8wAZcwAZs0AZswAZswAZswAZswAZsycBlETAAAAEHRSTlMAERpMbW6Bgry9xMXh5PP51ZZfkwAAAEdJREFUeNq9yEEKgDAMRNHERDWq6dz/tFLBQUC6KfRtPnzpsh/sC2AHrcRUo0iuDXONI7gMxVW9wIQWPFb5sMgMk5YTdMmvGw2DA8yS9di7AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-strike,
.ql-snow.ql-toolbar .ql-picker.ql-strike .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=strike],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=strike] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAn1BMVEUAAAAAAACAgIBAQEA7OztAQEBLS0tHR0dAQEBJSUlGRkZERERCQkJERERDQ0NERERERERDQ0NFRUVERERERERERERERERERERFRUVERERERERERERFRUVDQ0NFRUVERERFRUVFRUVERERFRUVFRUVFRUVERERFRUVFRUVERERERERERERERERERERERERERERERERERERERERERERERERfrjwTAAAANHRSTlMAAQIMDRAREhQVKCk6PEhLT1xkZWZ4e4CCg4SIiZucoaersLK2wcTFydLX2ODi5err8fX3BKZfrQAAAH5JREFUGBmlwOEWgTAYBuC3isgMxCYAmwRh++7/2qRzttP/HnQTZjdjilkALzhR4wBvQiaLk8WXOJwlHVHjYgxnSmbeR0swGEkpxWZ3vt7fL/w9P4/ist+KdZ7zYYiWiCnScFYiRq1HFo4mxaKIKdJw0ooaVQovkaW1pUzQyQ86Agx4yKmWPAAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-strike.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-strike .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=strike].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=strike].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-strike:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-strike .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=strike]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=strike]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAolBMVEUAAAAAAP8AgP8AatUAYsQAYM8AadIAY8YAZswAYc4AZswAZM0AZcoAZswAZ8oAZswAZMsAZ8oAZswAZcoAZ8sAZswAZssAZssAZs0AZswAZ8wAZs0AZ8wAZs0AZswAZ8wAZ8wAZs0AZ8wAZ8wAZs0AZs0AZs0AZcwAZs0AZcwAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsyiCU+yAAAANXRSTlMAAQIMDRAREhQVKCk6PEhLT1xkZWZ4e4CAgoOEiImbnKGnq7CytsHExcnS19jg4uXq6/H190B1i7AAAAB/SURBVBgZpcDhFoEwGAbgt4pIBmImAJsEYfvu/9ZU52yn/z3oxk/vWuczD453psYRzoR0GkaLHzFYSzqhwvgY1pT0vI8WbzASQvDt/nJ7fN6ovb7P/HrYrTdZxoY+WoJEkoK14iEqPTKwFMkkCBJJClZcUqOM4USiMKYQETr5A2SVDLpJv6ZtAAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-link,
.ql-snow.ql-toolbar .ql-picker.ql-link .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=link],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=link] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAllBMVEUAAAD///9VVVVJSUk5OTlAQEBHR0dFRUVCQkJHR0dBQUFCQkJGRkZDQ0NGRkZFRUVCQkJDQ0NERERDQ0NERERFRUVERERFRUVDQ0NERERFRUVERERERERFRUVERERERERERERERERFRUVERERFRUVFRUVERERERERERERERERERERERERERERERERERERERERERERERETx5KUoAAAAMXRSTlMAAAYHCQwZGiMkJzIzOUJOYGNlfoCJl5ibnaCxtLa8xsfIycrQ1OHi5uvs7e/19vn8NGTYeAAAAJdJREFUeNqN0McOgkAARdGnFJWiKGBhEEFpSn3//3OGjMmQ6MK7PMuLxVe/CXDTPl5DJmk3cOTTmZE7MDQES11RyhBY5vQU9aOB2z3gWVFMsXywYx3t9Q9tXsyDjlOVLQlOyanOL1ibkqB7l5odM01QSJqK6GdXmGwUHVhowImJIr2iMI9sLUWwa5LtFjPCSjSJBUl//HoDlmQPy0DFuCkAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-link.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-link .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=link].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=link].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-link:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-link .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=link]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=link]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAmVBMVEUAAAD///8AVdUAbdsAccYAatUAZswAYs4AZswAY80AacsAZswAZM0AZ8kAZM0AZcsAZcoAZMsAZcoAZcoAZssAZs0AZs0AZ8wAZs0AZswAZs0AZswAZs0AZswAZs0AZs0AZs0AZ8wAZswAZcwAZs0AZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsy/jsjWAAAAMnRSTlMAAAYHCQwZGiMkJzIzOUJOYGNlfoCAiZeYm52gsbS2vMbHyMnK0NTh4ubr7O3v9fb5/BM/koAAAACXSURBVHjajdDbEoFQAIXhpROqiAjaSdGJSq33fzjTbDO7GS78l9/lj9lXvwnw0le8gEzSuufAhzshr2doCpaGopQhoOX0Fb0GE9fbnidFMYV2Z8c62hgfWj6Z7zqOVY4kuCXHuqBgbUmC4Z9rdsx0QSFpLGKQXWCxUbRloQNHJoqMisI6sLUVwalJtitMCHPRJDYk/fHrDdIHECSPJag6AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-image,
.ql-snow.ql-toolbar .ql-picker.ql-image .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=image],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=image] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAElBMVEUAAABERERERERFRUVEREREREQbmEZBAAAABXRSTlMAeMTFxj7M9NAAAABBSURBVAjXY2DAD1RDQSAYyAqFABALLANmMRnAWMwODIIMUFnGUAEIS1A0NADMYgTqhLBY4SyEKXCTTcGMEAJuAgBa9RKl6Fva+wAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-image.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-image .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=image].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=image].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-image:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-image .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=image]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=image]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAElBMVEUAAAAAZswAZcwAZs0AZs0AZszYB6XUAAAABXRSTlMAeMTFxj7M9NAAAABBSURBVAjXY2DAD1RDQSAYyAqFABALLANmMRnAWMwODIIMUFnGUAEIS1A0NADMYgTqhLBY4SyEKXCTTcGMEAJuAgBa9RKl6Fva+wAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-list,
.ql-snow.ql-toolbar .ql-picker.ql-list .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=list],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=list] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAS1BMVEUAAABCQkJFRUVGRkZFRUVCQkJFRUVDQ0NFRUVFRUVFRUVERERERERERERERERFRUVERERERERERERERERERERERERERERERERERET32eciAAAAGHRSTlMAMjRCQ0lOfYKQlJmaocTFxuHi5OXm9falfyKhAAAATElEQVR42mMgFnCKYIpJMDDwSUABP1yIHyYkABYRlBAmwngucV50IXZGIXTjmQTZ0I0XIcp4DjEedCFWFlF041mZRdCN5xDjZiAdAACXwgbrzvG+ZgAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-list.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-list .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=list].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=list].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-list:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-list .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=list]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=list]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAS1BMVEUAAAAAZswAZ8kAZM0AZ8oAZcsAZcsAZswAZswAZ80AZs0AZs0AZ80AZ8wAZcwAZs0AZs0AZswAZswAZswAZswAZswAZswAZswAZswCB3gJAAAAGHRSTlMAMjRCQ0lOfYKQlJmaocTFxuHi5OXm9falfyKhAAAATElEQVR42mMgFnCKYIpJMDDwSUABP1yIHyYkABYRlBAmwngucV50IXZGIXTjmQTZ0I0XIcp4DjEedCFWFlF041mZRdCN5xDjZiAdAACXwgbrzvG+ZgAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-bullet,
.ql-snow.ql-toolbar .ql-picker.ql-bullet .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bullet],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bullet] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAABERERFRUVERERERETRGyWnAAAABHRSTlMAxMXG4b8ciAAAABxJREFUCNdjYMAPhBhdgMAJyFJmArGcGRgGXAcA/t0ImAOSO9kAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-bullet.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-bullet .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bullet].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bullet].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-bullet:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-bullet .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=bullet]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=bullet]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAAAAZcwAZs0AZs0AZsyEYJIjAAAABHRSTlMAxMXG4b8ciAAAABxJREFUCNdjYMAPhBhdgMAJyFJmArGcGRgGXAcA/t0ImAOSO9kAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-authorship,
.ql-snow.ql-toolbar .ql-picker.ql-authorship .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=authorship],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=authorship] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAARVBMVEUAAABFRUVFRUUAAAAAAABERERDQ0NEREQAAABERERERERERERERERERERFRUVERERERERERERERERERERERERERERERERVeSBUAAAAFnRSTlMAMDtOT1JfYmassMfN09Ta6vD4+fz9w8DTTwAAAExJREFUGBmVwEkSgCAMBMBRQUEU4zb/f6oFF5KbNLp4EQ8rkxnWQ76whBRYkYwwxo08ZijDzWJBs7La0ZysLjSJVUKXKSgOhQuKw08fJOYE1SddZQoAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-authorship.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-authorship .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=authorship].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=authorship].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-authorship:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-authorship .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=authorship]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=authorship]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAARVBMVEUAAAAAZcoAaMsAZc4AZ8sAZ8oAZswAZcsAZ80AZs0AZ8wAZ8wAZswAZswAZswAZs0AZswAZswAZswAZswAZswAZswAZszAoUIuAAAAFnRSTlMAMDtOT1JfYmassMfN09Ta6vD4+fz9w8DTTwAAAExJREFUGBmVwEkSgCAMBMBRQUEU4zb/f6oFF5KbNLp4EQ8rkxnWQ76whBRYkYwwxo08ZijDzWJBs7La0ZysLjSJVUKXKSgOhQuKw08fJOYE1SddZQoAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-color,
.ql-snow.ql-toolbar .ql-picker.ql-color .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=color],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=color] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAgVBMVEUAAAAAAACAgIBAQEBVVVVDQ0NGRkZGRkZFRUVERERDQ0NDQ0NDQ0NCQkIAAABFRUUAAABDQ0NEREREREREREQAAABDQ0NDQ0NERERFRUVERERERERERERDQ0NERERERERFRUVFRUVERERERERERERERERERERERERERERERERERERLPkdWAAAAKnRSTlMAAQIEBhMWISUtLkVMTU5OT1BTVlpmeX6OkJmdvL3GztTj5/Hy8/b3/f5utmv0AAAAX0lEQVR42pXIRQ6AQABDUdzd3bX3PyCWwAwr+Is2ecyvuKriXmQD5otKoKBFQz+sKkU5khQZKdK8yMoyiQTFOIseEbqLWv6mAPW+bAPvJmN0j/N7nfmTFRI5Jzk0fWwD4sYJPnqIyzwAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-color.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-color .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=color].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=color].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-color:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-color .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=color]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=color]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAgVBMVEUAAAAAAP8AgP8AgL8AVdUAa8kAaNEAZMkAZ8gAZswAZM0AZMsAZc0AZ8oAZcsAZc4AZ8sAZswAZcsAZc0AZswAZ80AZcoAZcoAZs0AZ80AZs0AZs0AZs0AZ8wAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsy3JBcuAAAAKnRSTlMAAQIEBhMWISUtLkVMTU5OT1BTVlpmeX6OkJmdvL3GztTj5/Hy8/b3/f5utmv0AAAAX0lEQVR42pXIRQ6AQABDUdzd3bX3PyCWwAwr+Is2ecyvuKriXmQB5otKoKBFQz+sKkU5khQZKdK8yMoyiQTFOIseEbqLWv6mAPW+bAPvJmN0j/N7nfmTHRI5Jzk0fWwD4foJPqgJbeoAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-background,
.ql-snow.ql-toolbar .ql-picker.ql-background .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=background],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=background] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAnFBMVEUAAAAAAACAgIBAQEAAAABVVVUAAAAAAAAAAABDQ0MAAABGRkZGRkYAAABFRUVERERDQ0MAAAAAAAAAAAAAAABDQ0MAAABDQ0MAAABCQkJFRUVDQ0NERERERERERERDQ0NDQ0NERERFRUVERERERERERERDQ0NERERERERFRUVFRUVERERERERERERERERERERERERERERERERERETMTXVbAAAAM3RSTlMAAQIEBgYHCBMTFBYhIyUtLjE2N0JFS0xNTU5QU1ZaeX6OkJmdvL3GztTj5/Hy8/b3/f5Qd6EEAAAAf0lEQVR42o2PRw6DQBRDHVJISCUhvTd69/3vhgT6MLPDmoX15KfRR++c6mdKgVIOTRFoeJ6hE+tCnjXRgUv+oc02jJNyrYk/vj/8jhRxnheLVZHNupn1Yp3nVIgzjhoUDlvxQR/AIOBtKbNjerUB+x7vhZjARPkLyslbYIe+qQDqMQxGJwkBGwAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-background.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-background .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=background].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=background].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-background:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-background .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=background]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=background]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAMAAABhEH5lAAAAllBMVEUAAAAAAP8AgP8AgL8AVdUAbbYAYL8Aa8kAZswAaNEAZMkAZswAZ8gAZswAZM0AaMsAaNAAZswAZM0AZMsAZswAZc0AZ8oAZ80AZcsAZswAZcsAZc0AZswAZcoAZcoAZs0AZ80AZs0AZs0AZs0AZ8wAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsy8dW5vAAAAMXRSTlMAAQIEBgcIExQWISMlLS4xNjdCRUtMTU1OUFNWWnl+jpCZnby9xs7U4+fx8vP29/3+dqGBzgAAAH5JREFUeNqNj0cOg0AUQx1CgFQS0nujd9//ckigDzM7rFlYT34afYzOuX2WFCjl0BWBRhAYOnEu5EkTPfjkH9pswzSr15r44/vDr6mI87JarKrCHmbOi22ethDPTDoUT3vxwRDAJOJtKbNjfnUB957uhVjATPkLyslbYIexaQB/ngudkm14XQAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-left,
.ql-snow.ql-toolbar .ql-picker.ql-left .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=left],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=left] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAABERERFRUVERERERETRGyWnAAAABHRSTlMAxMXG4b8ciAAAAClJREFUCNdjYMAPRFxcnCAsFRcXZwYiAFCHC0STCpjlTJwOJwaYDoIaAKIACBBRNsu4AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-left.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-left .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=left].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=left].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-left:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-left .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=left]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=left]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAAAAZcwAZs0AZs0AZsyEYJIjAAAABHRSTlMAxMXG4b8ciAAAAClJREFUCNdjYMAPRFxcnCAsFRcXZwYiAFCHC0STCpjlTJwOJwaYDoIaAKIACBBRNsu4AAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-right,
.ql-snow.ql-toolbar .ql-picker.ql-right .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=right],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=right] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAABERERFRUVERERERETRGyWnAAAABHRSTlMAxMXG4b8ciAAAAChJREFUCNdjYCAIRFxcnCAsFRcXZ2KUu0B0qIBZzgzEaXFigGkhpAMAmbwIEMJ9k/cAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-right.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-right .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=right].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=right].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-right:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-right .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=right]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=right]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAAAAZcwAZs0AZs0AZsyEYJIjAAAABHRSTlMAxMXG4b8ciAAAAChJREFUCNdjYCAIRFxcnCAsFRcXZ2KUu0B0qIBZzgzEaXFigGkhpAMAmbwIEMJ9k/cAAAAASUVORK5CYII="); }

.ql-snow.ql-toolbar .ql-format-button.ql-center,
.ql-snow.ql-toolbar .ql-picker.ql-center .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=center],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=center] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAABERERFRUVERERERETRGyWnAAAABHRSTlMAxMXG4b8ciAAAAC1JREFUCNdjYCAAGF1cXBTALCYgy4CBIBBxAQEnIEsFzHJmIMYKiCVMYBYhSwCyqQhMfft6AQAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-center.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-center .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=center].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=center].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-center:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-center .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=center]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=center]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAAAAZcwAZs0AZs0AZsyEYJIjAAAABHRSTlMAxMXG4b8ciAAAAC1JREFUCNdjYCAAGF1cXBTALCYgy4CBIBBxAQEnIEsFzHJmIMYKiCVMYBYhSwCyqQhMfft6AQAAAABJRU5ErkJggg=="); }

.ql-snow.ql-toolbar .ql-format-button.ql-justify,
.ql-snow.ql-toolbar .ql-picker.ql-justify .ql-picker-label,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=justify],
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=justify] {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASBAMAAACk4JNkAAAAD1BMVEUAAABERERFRUVERERERETRGyWnAAAABHRSTlMAxMXG4b8ciAAAABpJREFUCNdjYMAPRFxAwAnIUgGznBkYBlwHAJGzCjB/C3owAAAAAElFTkSuQmCC"); }

.ql-snow.ql-toolbar .ql-format-button.ql-justify.ql-active,
.ql-snow.ql-toolbar .ql-picker.ql-justify .ql-picker-label.ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=justify].ql-active,
.ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=justify].ql-selected,
.ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-justify:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-justify .ql-picker-label:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=justify]:hover,
.ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=justify]:hover {
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABIAAAASCAYAAABWzo5XAAAALklEQVR42mMYvoARzko9cwTIsyZR+zGGWcZgPUwIMUZGShwyGtijgT0a2EMMAADESwwWta/i5QAAAABJRU5ErkJggg=="); }

@media (-webkit-min-device-pixel-ratio: 2) {
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAIVBMVEUAAABCQkJDQ0NDQ0NERERERERERERERERERERERERERERehmmoAAAACnRSTlMATVRbaeXo6fz+NPhZJgAAAF9JREFUKM9jYBjkQC0JXYS5a4UBmpDFqlXN6IpWrUJTprEKCJpQhLJAQsswhZaiCImDhAJp5kMxkPGJZLjLEiQ0GUWIZdaqVSsdUM33XLVqCpqVLLPQFTEwmAcP9qQAAFUgKabkwE6gAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-picker.ql-expanded .ql-picker-label {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAJFBMVEWqqqr////AwMDAwMDAwMDBwcHBwcHBwcHBwcHBwcHBwcHBwcEexLCPAAAAC3RSTlMAAE1UW2nl6On8/tZA57EAAABxSURBVHjazc4hFkBAGMTxL3AAp+AGniYiyaLnBETHoKkknbc7l7OrzW7zhP3HX5mRxCskEsknEaZoU6VDNbAyRRugSqICpoVotnT7dBFllnpefPuHUpjGD78aSztRfAK65cUOOIQpPnXrkFSDEFFB0APtK1HCkKpz1wAAAABJRU5ErkJggg=="); }
  .ql-snow.ql-toolbar .ql-picker.ql-active:not(.ql-expanded) .ql-picker-label,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker:not(.ql-expanded) .ql-picker-label:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAIVBMVEUAAAAAZ8oAZMsAZc0AZswAZswAZswAZswAZswAZswAZswhMkyGAAAACnRSTlMATVRbaeXo6fz+NPhZJgAAAF9JREFUKM9jYBjkQC0JXYS5a4UBmpDFqlXN6IpWrUJTprEKCJpQhLJAQsswhZaiCImDhAJp5kMxkPGJZLjLEiQ0GUWIZdaqVSsdUM33XLVqCpqVLLPQFTEwmAcP9qQAAFUgKabkwE6gAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-bold,
  .ql-snow.ql-toolbar .ql-picker.ql-bold .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bold],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bold] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAxlBMVEUAAABVVVUzMzNVVVVJSUlGRkZAQEBJSUlAQEBAQEBAQEBHR0dCQkJGRkZAQEBGRkZCQkJERERDQ0NDQ0NGRkZERERDQ0NFRUVCQkJFRUVERERDQ0NDQ0NFRUVDQ0NERERERERERERERERERERERERERERERERERERFRUVDQ0NERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERfjmwgAAAAQXRSTlMAAwUGBwsMDhAUGBkbHSAhIykuOUJERUpNUVZYXGRne3yAi4+SmqWmq67R1tfY2dve5ujp7/Dy8/T19vf4+fv8/mUg1b0AAACrSURBVDjL5dPFDgJBEEXRxt3d3d11gPv/P8WCEAgZuno/b1WLk1TqJaWUI1Jc8852Mqz5bdHHALDK2CF+ckgYIHp/0GtypxpHYKlFSqkycJeQD7hIKADMJFQHulrkSrYs2MflCnZZgzKvo7RJmZeSAWIf1V3nihSGAG19BUq1gKmEQsBZQkHAklATmOuQN5zvP4COQQWnmIxuFfERWOTsXmrztWg8qHqUU/IEzOhNFx6Ncl4AAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-bold.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-bold .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bold].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bold].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-bold:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-bold .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=bold]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=bold]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAxlBMVEUAAAAAVaoAZswAVdUAbdsAXdEAatUAbcgAYM8AZswAasoAZswAaNAAasoAaMcAZMkAZswAZM0AZM0AZ8kAZM0AZcsAZMsAZMsAZ8oAZc0AZc0AZcsAZ8oAZswAZssAZssAZcwAZssAZ80AZs0AZ8wAZ80AZswAZ8wAZ8wAZ8wAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsyeO+aMAAAAQXRSTlMAAwUGBwsMDhAUGBkbHSAhIykuOUJERUpNUVZYXGRne3yAi4+SmqWmq67R1tfY2dve5ujp7/Dy8/T19vf4+fv8/mUg1b0AAACrSURBVDjL5dPFDgJBEEXRxt3d3d11gPv/P8WCEAgZuno/b1WLk1TqJaWUI1Jc8852Mqz5bdHHALDK2CF+ckgYIHp/0GtypxpHYKlFSqkycJeQD7hIKADMJFQHulrkSrYs2MflCnZZgzKvo7RJmZeSAWIf1V3nihSGAG19BUq1gKmEQsBZQkHAklATmOuQN5zvP4COQQWnmIxuFfERWOTsXmrztWg8qHqUU/IEzOhNFx6Ncl4AAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-italic,
  .ql-snow.ql-toolbar .ql-picker.ql-italic .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=italic],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=italic] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAjVBMVEUAAAAAAACAgIBAQEBVVVVAQEBAQEBCQkJCQkJFRUVDQ0NBQUFDQ0NDQ0NDQ0NFRUVERERERERERERDQ0NERERDQ0NERERERERERERFRUVFRUVERERFRUVERERERERDQ0NERERERERERERDQ0NFRUVEREREREREREREREREREREREREREREREREREREREQUqV1+AAAALnRSTlMAAQIEBggMGyMlKisuUFhZXmJmb3R9hIiKjZGTlKWprrG0uL3BxObt8PL19/j9SqrrawAAAIJJREFUOMvl0jUOQgEQRVHc3d1dzv6XRwch+WRq4NYnmVdMKvU35RZXz+7LQiJqe6uXiDrvqJuI8vM7ALd14fOwIabR+i1agUmfUA1QGedMgJrYRZPGGEVoh0ZgMmeUAlTBMbrWwiZCEwwitEc9MNkLigGq4RBda2MVoRn6X/jfv9YDjuYgGnCpSqcAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-italic.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-italic .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=italic].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=italic].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-italic:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-italic .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=italic]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=italic]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAjVBMVEUAAAAAAP8AgP8AgL8AVdUAYL8AatUAaNAAZswAZ8gAZ8gAZcoAZM0AZswAZcsAZMsAZMsAZcsAZ8sAZcoAZcoAZswAZs0AZ8wAZs0AZ8wAZswAZs0AZs0AZswAZ8wAZ8wAZs0AZswAZ8wAZ8wAZs0AZcwAZswAZswAZswAZswAZswAZswAZswAZswAZsyyI9XbAAAALnRSTlMAAQIEBggMGyMlKisuUFhZXmJmb3R9hIiKjZGTlKWprrG0uL3BxObt8PL19/j9SqrrawAAAIJJREFUOMvl0jUOQgEQRVHc3d1dzv6XRwch+WRq4NYnmVdMKvU35RZXz+7LQiJqe6uXiDrvqJuI8vM7ALd14fOwIabR+i1agUmfUA1QGedMgJrYRZPGGEVoh0ZgMmeUAlTBMbrWwiZCEwwitEc9MNkLigGq4RBda2MVoRn6X/jfv9YDjuYgGnCpSqcAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-underline,
  .ql-snow.ql-toolbar .ql-picker.ql-underline .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=underline],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=underline] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAWlBMVEUAAAAAAAAzMzNAQEBGRkZERERERERCQkJERERDQ0NFRUVERERERERFRUVERERERERERERFRUVERERERERERERDQ0NFRUVERERERERERERERERERERERERERET15sOLAAAAHXRSTlMAAQUMLC04TU9UVYePkJKkxMXG2Nrf4+jz9/n6/qlZ0HQAAACUSURBVHja7Y3BDsIgEAW3UCmCFatQxLL//5uuiQ0py1EPxs5tHhMW/oMhxoF5TUSMzGuQqH2PfiO60yiLStIHi260qqKKNLDI0XouOpI6Fh1f/x9W6xOpYZHwNM/9u5lJvACGzvSQRiWlOiUkNDSwuMFCi87mkmTbQRvt18aXWwxhXFiW4IyAr3LBJtMmmtrRFT7ME0B0HEswIOSJAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-underline.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-underline .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=underline].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=underline].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-underline:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-underline .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=underline]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=underline]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAWlBMVEUAAAAAAP8AZswAatUAaMsAZswAZM0AZ8oAZMsAZMsAZswAZswAZs0AZ80AZ8wAZ8wAZcwAZs0AZs0AZswAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZszogqY1AAAAHXRSTlMAAQUMLC04TU9UVYePkJKkxMXG2Nrf4+jz9/n6/qlZ0HQAAACUSURBVHja7Y3BDsIgEAW3UCmCFatQxLL//5uuiQ0py1EPxs5tHhMW/oMhxoF5TUSMzGuQqH2PfiO60yiLStIHi260qqKKNLDI0XouOpI6Fh1f/x9W6xOpYZHwNM/9u5lJvACGzvSQRiWlOiUkNDSwuMFCi87mkmTbQRvt18aXWwxhXFiW4IyAr3LBJtMmmtrRFT7ME0B0HEswIOSJAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-strike,
  .ql-snow.ql-toolbar .ql-picker.ql-strike .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=strike],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=strike] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAABLFBMVEUAAACAgIBVVVVAQEAzMzNVVVVAQEA5OTlNTU1JSUlERERHR0dDQ0NGRkZDQ0NAQEBCQkJAQEBGRkZAQEBGRkZERERBQUFERERGRkZCQkJGRkZERERFRUVERERDQ0NFRUVERERDQ0NFRUVCQkJDQ0NFRUVCQkJDQ0NERERDQ0NERERERERDQ0NFRUVERERERERERERERERFRUVERERDQ0NFRUVERERERERFRUVERERERERDQ0NDQ0NFRUVERERERERFRUVERERERERFRUVERERERERDQ0NERERFRUVERERERERERERFRUVERERERERERERERERFRUVERERERERERERFRUVERERERERERERERERERERERERERERERERERERERERERERERERERERERET5TTiyAAAAY3RSTlMAAgMEBQYICQoODxITFhcYGxwdICEtLzEzNjc4P0BFRkdISk1YWWBjaWtsdHZ3f4CHiImKjJGSk5SVl5ufo6Smp625uru8vb/BwsPExcbMzs/Q0dPi4+Tl6+zv8PL19vf4+/z2SQ4sAAABE0lEQVQ4y2NgGDmAV8c5PCkxxFGDE6cSDuOEZCiI0WXGroY/OBkJeHJhU8Pkm4wCXBixKFIHyUTqibJzS5lEgNhqWBT5AMWD+CFsHg8gxxuLoniguCyMIwLkxGFRBPKZDKEw8gMqCuAloEgb7HADMTZ8ijisjHTUlCSFOdgFxeVUNPXM7Z38QmJ9EApQxFFCyxeuxhtFPC7U39nBQl9LVV5CiAMpiFDEOYQlldR0jGwM8DmOVVDRLBpkpDIBr/KBXOBKKNSEgYpiMUQjgaLChBQ5A0W94AHO6wXkumEoUgY5NcpUUYCFRUDBNAqHw22T0YAdNp9bo6qxZMLqI4VAhJIgBZwelzZ0D4uLC3M3lB5B5QgAFQdgZ6NzzvYAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-strike.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-strike .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=strike].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=strike].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-strike:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-strike .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=strike]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=strike]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAABLFBMVEUAAAAAgP8AVaoAgL8AZswAVdUAYL8AccYAZswAbcgAZswAY8YAa8kAaNEAZMgAasoAaNAAZMgAasoAaMcAZMkAZswAZ8kAaMsAZM0AaMsAZswAZM0AZcoAZMsAZMsAZswAZc0AZ8oAZMsAZ8oAZcsAZMsAZcoAZMsAZswAZssAZssAZcoAZssAZcwAZssAZs0AZswAZ8wAZs0AZs0AZswAZswAZ8wAZs0AZs0AZ80AZ8wAZswAZ8wAZs0AZ8wAZ8wAZs0AZs0AZswAZ8wAZs0AZs0AZ8wAZcwAZs0AZ8wAZswAZcwAZs0AZs0AZ8wAZswAZswAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswL5dPDAAAAY3RSTlMAAgMEBQYICQoODxITFhcYGxwdICEtLzEzNjc4P0BFRkdISk1YWWBjaWtsdHZ3f4CHiImKjJGSk5SVl5ufo6Smp625uru8vb/BwsPExcbMzs/Q0dPi4+Tl6+zv8PL19vf4+/z2SQ4sAAABE0lEQVQ4y2NgGDmAV8c5PCkxxFGDE6cSDuOEZCiI0WXGroY/OBkJeHJhU8Pkm4wCXBixKFIHyUTqibJzS5lEgNhqWBT5AMWD+CFsHg8gxxuLoniguCyMIwLkxGFRBPKZDKEw8gMqCuAloEgb7HADMTZ8ijisjHTUlCSFOdgFxeVUNPXM7Z38QmJ9EApQxFFCyxeuxhtFPC7U39nBQl9LVV5CiAMpiFDEOYQlldR0jGwM8DmOVVDRLBpkpDIBr/KBXOBKKNSEgYpiMUQjgaLChBQ5A0W94AHO6wXkumEoUgY5NcpUUYCFRUDBNAqHw22T0YAdNp9bo6qxZMLqI4VAhJIgBZwelzZ0D4uLC3M3lB5B5QgAFQdgZ6NzzvYAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-link,
  .ql-snow.ql-toolbar .ql-picker.ql-link .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=link],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=link] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAABDlBMVEUAAAD///8AAACAgIBVVVVAQEAzMzNVVVVAQEBNTU1HR0dAQEBJSUlGRkZDQ0NAQEBERERHR0dGRkZDQ0NBQUFGRkZERERCQkJGRkZFRUVCQkJFRUVERERDQ0NDQ0NCQkJFRUVDQ0NERERDQ0NFRUVDQ0NFRUVFRUVFRUVFRUVERERDQ0NFRUVERERFRUVERERERERDQ0NFRUVFRUVERERERERERERERERFRUVERERERERERERFRUVDQ0NERERERERFRUVERERERERERERERERERERERERERERERERERERERERFRUVERERERERERERERERERERERERERERERERERERERERERERERERERERERESFPz0UAAAAWXRSTlMAAAECAwQFBggKEhQVFhccHiQoKissLTIzNDpGR0hMTU5QUlRVW12BgoaHjI2PmJmam5ygpKWosbKztLW6vcDD0NLT2Nna3N7g4eLj5Ofo6err7u/w8vn7/A90CXkAAAFqSURBVDjLzdTHUgJREIXho8yo6JgFc0LFjAkVMZAFJYrCzP/+L+JCtJipS5U7Patbt79Vd1dr6BfRHyBJUiie6dSSiwrEh2aeAPAO7cEoUqWXdHgQirQAOh7A46gZzVQBzsfmSgAnRhR6AjiS5OQAd9aE4t9GmqoCCRPKAGe9zzhQDxlQBzpjknab9c2RD2DBgGrgzUlqQnfrHlg3oGug6Eh1oFsAEtvLVhAteUBuSjseP2lfzQf6dARQjY/s9SncY9uH7DQA7+ky/XkI+8YSfvRVC6k3AO4s34BHT90+1N2yYq8A+/5V0Wyi0ac2NJkD3KgfSaGF9QRQ9oCC5JSAiyCStA2k9jzISooCFQNaBlpWrJBdkTThQsOA7DYQ+3pbKeDWgHQFvDiSNJwEWDWheRfIOZKVBLiRCekYoBiZSAHkx83IfgDABXielhkpfAcAkJ/WICTrwAXgZlyDkRS9rDRu1wJL98/u0yeVYHcP1mwWWgAAAABJRU5ErkJggg=="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-link.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-link .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=link].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=link].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-link:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-link .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=link]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=link]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAABDlBMVEUAAAD///8AAP8AgP8AVaoAgL8AZswAVdUAYL8AZswAY8YAZswAYc4AaNEAZMgAZMgAZswAY80AZswAZ8gAZcoAaMsAZswAZswAZM0AZ8kAZcoAZswAZc0AZ8oAZc0AZ8oAZcsAZswAZ8oAZMsAZswAZc0AZcsAZ84AZswAZ84AZswAZswAZ8wAZs0AZs0AZs0AZ80AZswAZ8wAZswAZ8wAZswAZs0AZs0AZs0AZ8wAZswAZ8wAZ8wAZ8wAZs0AZswAZs0AZswAZswAZswAZswAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsxCnEEHAAAAWXRSTlMAAAECAwQFBggKEhQVFhccHiQoKissLTIzNDpGR0hMTU5QUlRVW12BgoaHjI2PmJmam5ygpKWosbKztLW6vcDD0NLT2Nna3N7g4eLj5Ofo6err7u/w8vn7/A90CXkAAAFqSURBVDjLzdTHUgJREIXho8yo6JgFc0LFjAkVMZAFJYrCzP/+L+JCtJipS5U7Patbt79Vd1dr6BfRHyBJUiie6dSSiwrEh2aeAPAO7cEoUqWXdHgQirQAOh7A46gZzVQBzsfmSgAnRhR6AjiS5OQAd9aE4t9GmqoCCRPKAGe9zzhQDxlQBzpjknab9c2RD2DBgGrgzUlqQnfrHlg3oGug6Eh1oFsAEtvLVhAteUBuSjseP2lfzQf6dARQjY/s9SncY9uH7DQA7+ky/XkI+8YSfvRVC6k3AO4s34BHT90+1N2yYq8A+/5V0Wyi0ac2NJkD3KgfSaGF9QRQ9oCC5JSAiyCStA2k9jzISooCFQNaBlpWrJBdkTThQsOA7DYQ+3pbKeDWgHQFvDiSNJwEWDWheRfIOZKVBLiRCekYoBiZSAHkx83IfgDABXielhkpfAcAkJ/WICTrwAXgZlyDkRS9rDRu1wJL98/u0yeVYHcP1mwWWgAAAABJRU5ErkJggg=="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-image,
  .ql-snow.ql-toolbar .ql-picker.ql-image .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=image],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=image] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAFVBMVEUAAABCQkJEREREREREREREREREREQL6X1nAAAABnRSTlMATXjl6OmAFiJpAAAAZklEQVR42sXQsQ3AIAxEUeQZoKdyzwg0DALo9h8hiCYXo4R0/MbSK1ycO5EHlScVpj4Jj97p/vtJPi9U+kptXIlMIY2r1b4XIBpSoDJJFIyYtKohAWBIV8Ke9kv8X7WwtEmBKbkDXfWkWdehkaSCAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-image.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-image .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=image].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=image].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-image:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-image .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=image]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=image]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAFVBMVEUAAAAAZ8oAZswAZswAZswAZswAZsx4QzxlAAAABnRSTlMATXjl6OmAFiJpAAAAZklEQVR42sXQsQ3AIAxEUeQZoKdyzwg0DALo9h8hiCYXo4R0/MbSK1ycO5EHlScVpj4Jj97p/vtJPi9U+kptXIlMIY2r1b4XIBpSoDJJFIyYtKohAWBIV8Ke9kv8X7WwtEmBKbkDXfWkWdehkaSCAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-list,
  .ql-snow.ql-toolbar .ql-picker.ql-list .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=list],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=list] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAw1BMVEUAAAAAAABVVVVAQEBERERAQEBJSUlGRkZHR0dFRUVCQkJERERAQEBGRkZDQ0NFRUVDQ0NCQkJGRkZDQ0NCQkJERERDQ0NFRUVERERFRUVERERDQ0NERERERERDQ0NFRUVERERERERERERERERERERERERERERFRUVERERERERERERFRUVERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERESFbZw4AAAAQHRSTlMAAQYIDxAVFhkaGx4gKCo0NTY3OU10fYKIiYqMj56fo6SmqKmvtLe6vr/ExcbLz9fh4uXm5+jp7O/w8vP3+vv9Z7IwDAAAAK1JREFUOMvV0scOglAQQFGwYO+oiIq9YldEFPX+/1e5cGEii2FFdNY3b/JORlF+dAqNrS1GQyDEW+9Id/gaRw9EgQacMNEhuO4caD7rlgDS/2yAVWTiia53HWeEaMLzwUKIdvt08n4TxLMptc1UEo/38YqCuGZzKknimxDi6jpa8Vjn6I4kcQNgLkSmVSvjizeeb9ITbzxXxxLETatSxRfEWwAzicC4uANN+at5AdptTQ0Ubk4LAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-list.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-list .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=list].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=list].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-list:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-list .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=list]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=list]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAw1BMVEUAAAAAAP8AVdUAYL8AZswAYM8AYc4AaNEAZswAYs4AaNAAZswAaMcAZswAZ8gAZ8kAZcoAaMsAZswAZ8kAZ8oAZcoAZswAZswAZ8wAZs0AZs0AZswAZs0AZs0AZ8wAZs0AZ8wAZ8wAZs0AZ8wAZswAZswAZs0AZ8wAZswAZcwAZcwAZs0AZs0AZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZszno9YmAAAAQHRSTlMAAQYIDxAVFhkaGx4gKCo0NTY3OU10fYKIiYqMj56fo6SmqKmvtLe6vr/ExcbLz9fh4uXm5+jp7O/w8vP3+vv9Z7IwDAAAAK1JREFUOMvV0scOglAQQFGwYO+oiIq9YldEFPX+/1e5cGEii2FFdNY3b/JORlF+dAqNrS1GQyDEW+9Id/gaRw9EgQacMNEhuO4caD7rlgDS/2yAVWTiia53HWeEaMLzwUKIdvt08n4TxLMptc1UEo/38YqCuGZzKknimxDi6jpa8Vjn6I4kcQNgLkSmVSvjizeeb9ITbzxXxxLETatSxRfEWwAzicC4uANN+at5AdptTQ0Ubk4LAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-bullet,
  .ql-snow.ql-toolbar .ql-picker.ql-bullet .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bullet],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bullet] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAABCQkJEREREREREREREREQc4xmxAAAABXRSTlMATeXo6UtNtyIAAAAzSURBVCjPY2AYACBsyCAcCgOGYCHTYAZTuFAwRCgISSgILCSiyCACF1JkGBgw6voBcj0AFsUtDasGrUcAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-bullet.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-bullet .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=bullet].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=bullet].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-bullet:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-bullet .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=bullet]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=bullet]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAAAAZ8oAZswAZswAZswAZsxixJGvAAAABXRSTlMATeXo6UtNtyIAAAAzSURBVCjPY2AYACBsyCAcCgOGYCHTYAZTuFAwRCgISSgILCSiyCACF1JkGBgw6voBcj0AFsUtDasGrUcAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-authorship,
  .ql-snow.ql-toolbar .ql-picker.ql-authorship .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=authorship],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=authorship] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAllBMVEUAAACAgIBAQEBCQkIAAABCQkJAQEBGRkZERERERERCQkJGRkZDQ0NDQ0NDQ0MAAAAAAAAAAABDQ0NFRUVERERFRUVERERFRUVERERFRUVERERERERERERERERERERERERERERFRUVEREREREREREREREREREREREREREREREREREREREREREREREREREREREREREREREQe3JVeAAAAMXRSTlMAAhgbHx8gIS0xMjM5VFdcXWZyd3yChImPkKy4yMrO0tPj5ebq7e7v8PLz9/j6/P3+mEwo9QAAAJxJREFUGBnVwNcOgjAYBeCj4l7FjeAGUZzn/V9O0kikSftf44c/0A+Tc9iFqHll7tKEJKAWQLKjtockpZZC8qL2hiSjlkESUYsgmVNbQtKhNoCgNrwz95w14NTe8Os2gUP9wJ8p7NYsebRg06NhAZsVDRFstjQksMlogs2Rhhg2o5glpxGqz1O+g/JQUL6TQkH5TmMUPOU7jD1U1AdG8S1kERvjygAAAABJRU5ErkJggg=="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-authorship.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-authorship .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=authorship].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=authorship].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-authorship:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-authorship .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=authorship]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=authorship]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAllBMVEUAAAAAgP8AasoAaNAAY84AaMcAZMkAZswAaMsAZswAZM0AZ8kAZMsAZ8oAZ8oAZcsAZc4AZ80AZcwAZcwAZcwAZswAZs0AZs0AZs0AZ80AZs0AZ8wAZswAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsyCDIYeAAAAMXRSTlMAAhgbHyAhLTEyMzlUV1xdXWZyd3yChImPkKy4yMrO0tPj5ebq7e7v8PLz9/j6/P3+PxHOPAAAAJxJREFUGBnVwNcOgjAYBeCj1j0q7oEbRHGe9385SSORJu1/jR/+QGcdn9ctiNSVmYuCZEljCcmOxh6ShEYCyYvGG5KURgpJSCOEZEpjDkmTRheCSu/OzHNSg1djw6/bCB7VA3/GcFux4FGHS5uWGVwWtIRw2dISwyWlDS5HWiK49CMWnPooP6UDD62Q04GXRk4HXgPk1DDwGCiU1AcZWy1RmD8CRQAAAABJRU5ErkJggg=="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-color,
  .ql-snow.ql-toolbar .ql-picker.ql-color .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=color],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=color] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAAz1BMVEUAAAAAAACAgIBVVVVAQEBVVVU5OTk7OztLS0tHR0dGRkZCQkIAAABERERDQ0NDQ0NDQ0NDQ0NGRkZERERERERCQkJFRUVERERFRUVEREQAAAAAAABDQ0NFRUVEREQAAABERERFRUVERERDQ0NDQ0NERERERERERERERERERERERERERERERERERERFRUVFRUVERERERERERERERERERERDQ0NERERERERERERERERERERERERERERERERERERERERERERERERERERERERERERbYaT1AAAARHRSTlMAAQIDBAYJDRESFhsfIiYqNUFCREtNVVZZWlxdY2RlZm1zdXZ9hI6Tl6Sws7nExcnS09XY2d/g5ejp6+zt8PP09/n9/idH/qoAAADKSURBVBgZ1cDXUsJAAIXhg2KMGruxsGoUe8cWoij1f/9nYiZDGJjsLrfwaRHEWRZrhuAXWoH8zgBO5VVpADTktU9uVz5P5B7lsdUn19+U2x3w+gbcyilsA0cnwP+qXOpAWl1pAhdyqKZAXboGvpZkdwi0Q2m9CxzI7oUJz7LaYdJgWzYPTLmXxUaPKZ01ld0A7xXllr+BK5VlwLlGLoFPlWXQCjQSduBDZfFPM9bY8V+6p7kXmcTBRCqYxMmoYBKnmgqRSRxqkebUEKsKOlxMa6IbAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-color.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-color .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=color].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=color].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-color:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-color .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=color]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=color]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAA0lBMVEUAAAAAAP8AgP8AVaoAgL8AVdUAccYAYsQAadIAY8YAaNEAaNAAY84AacsAZckAZ8gAZcoAZswAZM0AZcsAZswAZ8oAZswAZc0AZMsAZswAZ8oAZcsAZc4AZMsAZswAZcoAZ80AZcwAZswAZssAZssAZswAZs0AZs0AZs0AZ8wAZ8wAZ8wAZ8wAZswAZcwAZs0AZcwAZswAZswAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswVaivDAAAARXRSTlMAAQIDBAYJDRESFhsfIiYqNUFCREtNVVZZWlxdXWNkZWZtc3V2fYSOk5eksLO5xMXJ0tPV2Nnf4OXo6evs7fDz9Pf5/f6Y2SWXAAAAy0lEQVQYGdXA11LCQACF4YNijBq7sbCWKPaOLURREPjf/5WYyRAGJrvLLXyaB3GWxZoi+IFWIL9TgBN5VRoADXntktuWzyO5B3ls9Mj11uV2C7y8AjdyCtvAwRHwtyyXOpBWl5rAuRyqKVCXroDPBdntA+1QWv0H9mT3zJgnWW0xrr8pm3sm3MlircuEzorKroG3inKLX8ClyjLgTEMXwIfKMmgFGgo78K6y+LsZa+TwN93RzItM4mAiFUziZFQwiVNNheg4cahFmlEDFzs7cwmPHM8AAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-background,
  .ql-snow.ql-toolbar .ql-picker.ql-background .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=background],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=background] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAA4VBMVEUAAAAAAACAgIBVVVVAQEBVVVU5OTk7OztLS0tHR0dGRkZCQkJERERDQ0NDQ0NDQ0NDQ0NERERCQkJEREQAAAADAwMGBgZDQ0NEREQODg5ERERDQ0NFRUVERERERERERERDQ0MiIiJDQ0MmJiZEREQrKytEREREREQyMjIyMjJEREREREREREQ4ODhERERERERFRUVFRUVERERERERERERERERAQEBERERERERBQUFERERERERERERBQUFERERERERERERBQUFERERERERERERDQ0NERERERERDQ0NERERERESZD8GyAAAASnRSTlMAAQIDBAYJDRESFhsiJio1QURJS01QU1RWWVpjZGVtdXZ4fYCEiI6TnZ6ksLO3ucTFydLT193g4OLl5ebn6enq6+7w8vP39/n+/rihcb4AAADbSURBVHjazZPFDsMwEERdZkpTZmbmpszd//+grhpFSaS1e+khc1jbmrG1z7KZdSXLgvo79M9ziKCkKJIeoUPJA8AxKT6H5QGVE3dlmwJqKqaLwVdRIV1fDfVEdKGXGnoFBXQtDIwnWJp8uswd/XQWy8XD7aqD9srp2uJQ5NElVuiWGKvisLFz6Bpo3ryM+R84iXO6GoFBQ5ouAka9wyRdF0waUHSBpzl09xF0dTRmNnXu2OOiTNDtAKCg7W3jYk7QnQGObu0KvVeAJUFXU9aS/h5Sp0VFtui/s6w+XSJAbiVJ3G0AAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-background.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-background .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=background].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=background].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-background:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-background .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=background]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=background]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkCAMAAADW3miqAAAA5FBMVEUAAAAAAP8AgP8AVaoAgL8AZswAVdUAYL8AccYAYsQAadIAY8YAaNEAasoAZswAYsQAaNAAacsAZckAadEAZ8gAZcoAZswAZswAZMkAZM0AZcsAZ8sAZswAaM0AZ8oAZ80AZswAZc0AZMsAZswAZMsAZswAZcoAZcwAZswAZssAZssAZswAZs0AZs0AZs0AZ8wAZ8wAZ8wAZ8wAZswAZcwAZs0AZcwAZswAZswAZs0AZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZswAZsxJPDLdAAAAS3RSTlMAAQIDBAUGCAkNERIWGBkaGyImJyo1N0FCQkRFS0xNTVVWWVpjZGVtc3V2fYSOk5eksLO5xMXJ0tPV2Nnf4OXo6evs7fDz9Pf5/f60OfwzAAABG0lEQVR42s2T6VKDQBCEGyUJoqgSjcYg8dZ43/EieCUa5/3fx661qMAu7O98P4bZnq5lZlkwvXS7k1hf1BTdZFEsFpvUMU15IU7TuKiYJu9d5MODZZ8WcCBk39ZVAKcvpG+ZrgNsimIdTtV0TeBGFNewdBWORTFesUx3QcP9A8N59XT+kPWdPYavOQQVXfVYTtz6gI8jvfUsdRNWe8ApHy8z5ftgm8WhDyx8M4nKumoBd5LjVkkaAdYkz+8qpQLqtK+kwKU5XRPLP1JgNF8y3RkLjw4Us69cnMDb0qdLqR9myjEXz2brNPG2NSKQqOGPRJ5gEr8NYoT/9yHE7mfShoarovYptDw7kiWLyZTbNZBa9saK33tDWZlPK39U3ELkzhssBgAAAABJRU5ErkJggg=="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-left,
  .ql-snow.ql-toolbar .ql-picker.ql-left .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=left],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=left] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAABCQkJEREREREREREREREQc4xmxAAAABXRSTlMATeXo6UtNtyIAAABCSURBVCjPY2AYACAcCgaGSEKmEKFgTKEgJCERiJAiw0ACqOuR/WCKLBSMKRSE7PqB9YMwuttRnBqMKRSEGvYD6HYAD8opyeJDvUUAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-left.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-left .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=left].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=left].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-left:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-left .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=left]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=left]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAAAAZ8oAZswAZswAZswAZsxixJGvAAAABXRSTlMATeXo6UtNtyIAAABCSURBVCjPY2AYACAcCgaGSEKmEKFgTKEgJCERiJAiw0ACqOuR/WCKLBSMKRSE7PqB9YMwuttRnBqMKRSEGvYD6HYAD8opyeJDvUUAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-right,
  .ql-snow.ql-toolbar .ql-picker.ql-right .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=right],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=right] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAABCQkJEREREREREREREREQc4xmxAAAABXRSTlMATeXo6UtNtyIAAABCSURBVCjPY2AYMCAcCgaGSEKmEKFgTKEgJCERiJDiwLob2fWmyELBmEJByO4eWNejuN8QNZCRw94U3fUo7h8Q1wMAuRspyVIXC2UAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-right.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-right .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=right].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=right].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-right:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-right .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=right]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=right]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAAAAZ8oAZswAZswAZswAZsxixJGvAAAABXRSTlMATeXo6UtNtyIAAABCSURBVCjPY2AYMCAcCgaGSEKmEKFgTKEgJCERiJDiwLob2fWmyELBmEJByO4eWNejuN8QNZCRw94U3fUo7h8Q1wMAuRspyVIXC2UAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-center,
  .ql-snow.ql-toolbar .ql-picker.ql-center .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=center],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=center] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAABCQkJEREREREREREREREQc4xmxAAAABXRSTlMATeXo6UtNtyIAAABCSURBVCjPY2AYGCAcCgaGSEKmEKFgTKEgJCERiJAiw4ABqNORPWCKLBSMKRSE7PQB9oAwuuNR3BqMKRSEGvID53gA5GspyQ9EElMAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-center.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-center .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=center].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=center].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-center:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-center .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=center]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=center]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAAAAZ8oAZswAZswAZswAZsxixJGvAAAABXRSTlMATeXo6UtNtyIAAABCSURBVCjPY2AYGCAcCgaGSEKmEKFgTKEgJCERiJAiw4ABqNORPWCKLBSMKRSE7PQB9oAwuuNR3BqMKRSEGvID53gA5GspyQ9EElMAAAAASUVORK5CYII="); }
  .ql-snow.ql-toolbar .ql-format-button.ql-justify,
  .ql-snow.ql-toolbar .ql-picker.ql-justify .ql-picker-label,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=justify],
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=justify] {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAABCQkJEREREREREREREREQc4xmxAAAABXRSTlMATeXo6UtNtyIAAAAoSURBVCjPY2AYACAcigQMwUKmyELBmEJBYCERZCFFhoEBo64fINcDAAcQNGkJNhVcAAAAAElFTkSuQmCC"); }
  .ql-snow.ql-toolbar .ql-format-button.ql-justify.ql-active,
  .ql-snow.ql-toolbar .ql-picker.ql-justify .ql-picker-label.ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-label[data-value=justify].ql-active,
  .ql-snow.ql-toolbar .ql-picker .ql-picker-item[data-value=justify].ql-selected,
  .ql-snow.ql-toolbar:not(.ios) .ql-format-button.ql-justify:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker.ql-justify .ql-picker-label:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-label[data-value=justify]:hover,
  .ql-snow.ql-toolbar:not(.ios) .ql-picker .ql-picker-item[data-value=justify]:hover {
    background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACQAAAAkBAMAAAATLoWrAAAAElBMVEUAAAAAZ8oAZswAZswAZswAZsxixJGvAAAABXRSTlMATeXo6UtNtyIAAAAoSURBVCjPY2AYACAcigQMwUKmyELBmEJBYCERZCFFhoEBo64fINcDAAcQNGkJNhVcAAAAAElFTkSuQmCC"); } }

.ql-snow .ql-tooltip {
  border: 1px solid #ccc;
  box-shadow: 0px 0px 5px #ddd;
  color: #222; }

.ql-snow .ql-tooltip a {
  color: #06c; }

.ql-snow .ql-tooltip .input {
  border: 1px solid #ccc;
  margin: 0px;
  padding: 5px; }

.ql-snow a {
  color: #06c; }
.orchestra-quill-wrapper {
  background-color: #fff;
  border-left: 1px solid #ccc;
  border-right: 1px solid #ccc;
  box-shadow: 0px 0px 10px #ccc;
  margin-left: auto;
  margin-right: auto;
  width: 100%; }
  .orchestra-quill-wrapper .orchestra-quill-editor {
    height: 400px; }
  .orchestra-quill-wrapper .orchestra-quill-toolbar {
    margin-top: 15px;
    border-bottom: 1px solid #ccc;
    border-top: 1px solid #ccc; }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

.website-iframe {
  width: 100%;
  border: 1px solid #cccccc; }
.collapsed-toggle {
  cursor: pointer; }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

/**
 * Base stylesheet for Orchestra.
 *
 * This partial styles the base Django template and serves as the foundation for
 * each Orchestra view.
 */
html, body {
  font-size: 10px; }

section.wrapper {
  margin-top: 52px; }

section#main-content {
  margin-left: 0;
  color: #3c3c3c; }

header.header {
  background: #00598c;
  box-shadow: 0 1px 3px black;
  min-height: 0; }

h1, h2, h3, h4, h5, h6, p {
  margin: 0;
  padding: 0; }

a {
  color: #0079bf;
  text-decoration: none; }
  a:hover, a:focus, a:visited {
    color: #0079bf;
    text-decoration: underline; }

a.logo {
  font-size: 2rem;
  color: white;
  margin: 12px 30px; }
  a.logo:hover, a.logo:focus, a.logo:visited {
    color: white; }

.work-timer {
  float: right;
  height: 52px; }

#nav-options {
  cursor: pointer;
  font-size: 2rem;
  color: white;
  float: right;
  margin: 12px 30px;
  z-index: 1003; }
  #nav-options .dropdown-menu a {
    color: #0079bf; }
    #nav-options .dropdown-menu a:hover {
      color: #0079bf;
      text-decoration: underline; }

#hijacked-warning {
  left: 25%;
  width: 50%;
  border-radius: 0 0 5px 5px; }
  #hijacked-warning > span:last-child {
    margin-right: 0 !important; }

.section-panel {
  margin: 1.5rem;
  box-shadow: 0 1px 3px black;
  background-color: white; }
  .section-panel .section-header {
    margin-top: 0;
    color: white;
    background-color: #0079bf; }
    .section-panel .section-header h3 {
      margin: 1.3rem 0;
      font-size: 1.8rem; }
    .section-panel .section-header .btn {
      display: inline-block;
      color: white;
      background-color: #2ecc71; }
      .section-panel .section-header .btn:first-child {
        margin-left: 1.5rem; }
      .section-panel .section-header .btn:hover:not(.disabled) {
        border: 1px solid white; }
      .section-panel .section-header .btn.disabled {
        color: #cccccc;
        background-color: rgba(46, 204, 113, 0.6); }
  .section-panel .row:not(.section-header).padded > [class*="col-"] {
    padding-top: 1.5rem;
    padding-bottom: 1.5rem; }

.main-content {
  margin: 100px auto 0; }

.tasks-section .section-header .warning-message {
  font-style: italic;
  margin-left: 1.5rem;
  font-size: 1.5rem; }

.tasks-section .section-header .btn-new-task, .tasks-section .section-header .btn-new-entry-task, .tasks-section .section-header .btn-new-review-task {
  width: 150px;
  margin: 0 5px; }

.tasks-section .section-header .btn-new-entry-task {
  background-color: #27ae60; }
  .tasks-section .section-header .btn-new-entry-task.disabled {
    background-color: rgba(39, 174, 96, 0.6); }

.tasks-section .section-header .btn-new-review-task {
  background-color: #2ecc71; }
  .tasks-section .section-header .btn-new-review-task.disabled {
    background-color: rgba(46, 204, 113, 0.6); }

.tasks-section tr.task-row {
  cursor: pointer; }

.tasks-section .table {
  margin-bottom: 0;
  font-size: 1.4rem; }

.tasks-section .row {
  overflow-x: scroll; }

.tasks-section .st-sort-ascent:after {
  content: '\25B2'; }

.tasks-section .st-sort-descent:after {
  content: '\25BC'; }

.tasks-section .tasks-search-bar-container {
  display: flex;
  justify-content: flex-end; }

.tasks-section .tasks-search-bar {
  margin: 5px 10px;
  max-width: 150px;
  background: white;
  border: #cccccc 1px solid;
  color: #3c3c3c;
  display: flex;
  justify-content: flex-start;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  width: 100%;
  height: 34px;
  font-size: 14px;
  line-height: 1.42857143;
  border-radius: 3px; }
  .tasks-section .tasks-search-bar i {
    padding: 8px;
    color: #cccccc; }
  .tasks-section .tasks-search-bar input {
    height: 100%;
    width: calc(100% - 30px);
    padding: 8px 2px 10px 2px;
    border: none; }
    .tasks-section .tasks-search-bar input:focus {
      outline: none; }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select, .project-management .task-view .add-assignment, .project-management .task-view .worker-name, .project-management .project-actions {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

.project-management .overlay .spinner::after {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  border-bottom: 1px solid black;
  border-right: 1px solid black;
  border-radius: 50%;
  content: "";
  animation: spin .75s linear infinite; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

.project-management-modal, .slack-modal, .data-modal, .revert-modal {
  font-size: 1.5rem;
  padding: 15px; }
  .project-management-modal .json-view, .slack-modal .json-view, .data-modal .json-view, .revert-modal .json-view {
    margin-top: 10px;
    max-height: 50vh; }

.slack-modal input {
  width: 200px; }

.slack-modal .add-user {
  cursor: pointer;
  color: #2ecc71; }

.slack-modal .remove-user {
  cursor: pointer;
  color: red; }

.data-modal .header-wrapper {
  overflow: auto; }
  .data-modal .header-wrapper .data-header {
    float: left; }
  .data-modal .header-wrapper .btn-admin {
    float: right; }

.revert-modal .header-wrapper {
  overflow: auto; }

.project-management {
  margin-top: 75px;
  font-size: 1.5rem;
  position: relative; }
  .project-management .overlay {
    position: absolute;
    top: 0;
    left: 20px;
    right: 20px;
    bottom: 0;
    background-color: white;
    opacity: 0.75;
    z-index: 100; }
    .project-management .overlay .spinner {
      position: absolute;
      width: 40px;
      height: 40px;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%); }
  .project-management .project-description.ui-select-bootstrap {
    margin: 10px 0; }
    .project-management .project-description.ui-select-bootstrap > .ui-select-match > .btn {
      height: auto;
      width: auto;
      font-size: 30px;
      padding-right: 40px; }
  .project-management .axis-wrapper {
    position: relative;
    display: inline-block; }
  .project-management .axis {
    shape-rendering: crispEdges; }
    .project-management .axis.x line {
      stroke: #000; }
    .project-management .axis.x path {
      fill: none;
      stroke: #000; }
  .project-management .x.label {
    color: black;
    position: absolute; }
  .project-management svg {
    vertical-align: top;
    overflow: visible; }
  .project-management .task-view {
    position: relative;
    display: inline-block; }
    .project-management .task-view .add-assignment {
      display: block;
      cursor: pointer;
      text-align: right; }
    .project-management .task-view .worker-name {
      display: block;
      cursor: pointer;
      text-align: right;
      background-color: inherit; }
      .project-management .task-view .worker-name.readonly {
        outline: none;
        border: none; }
  .project-management .vis-wrapper {
    position: relative;
    margin-bottom: 75px;
    min-height: 200px; }
    .project-management .vis-wrapper .svg-wrapper {
      overflow-x: auto;
      overflow-y: hidden;
      position: relative; }
    .project-management .vis-wrapper .freeze-pane-left {
      position: absolute;
      top: 0;
      bottom: 0;
      left: 0;
      background-color: white;
      text-align: right;
      border-right: 1px solid #333;
      min-width: 225px; }
      .project-management .vis-wrapper .freeze-pane-left .scale-buttons {
        position: absolute;
        top: 0;
        right: 0;
        padding-right: 10px; }
      .project-management .vis-wrapper .freeze-pane-left .task-name {
        padding: 0 10px; }
        .project-management .vis-wrapper .freeze-pane-left .task-name .step-status {
          font-size: 0.8em; }
        .project-management .vis-wrapper .freeze-pane-left .task-name .task-action {
          margin-left: 5px; }
  .project-management .project-actions {
    display: inline-block;
    cursor: pointer; }
    .project-management .project-actions .project-actions-menu {
      font-size: 2em; }
  .project-management .task-rect {
    cursor: pointer; }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

/* Confirmation modals */
.modal-confirm-submit {
  padding-top: 200px; }

.modal-confirm-header {
  border-top-left-radius: 5px;
  border-top-right-radius: 5px; }

.modal-header {
  background: #0079bf; }

.modal-confirm-body {
  overflow: auto;
  width: 300px; }
  .modal-confirm-body hr {
    margin: 0px 0px 3px 0px; }
  .modal-confirm-body .time-error-message {
    color: red;
    text-align: right;
    font-size: 1.2rem;
    padding-right: 9px; }
  .modal-confirm-body .time-question {
    margin-bottom: 3px; }
  .modal-confirm-body .time-summary {
    overflow: auto;
    padding-bottom: 3px; }
    .modal-confirm-body .time-summary .form-control {
      width: 30px;
      padding: 2px;
      height: 23px;
      text-align: right; }
    .modal-confirm-body .time-summary .time-label {
      float: left; }
    .modal-confirm-body .time-summary .time-report {
      float: right; }
      .modal-confirm-body .time-summary .time-report .time-unit-group {
        float: left;
        width: 70px; }
        .modal-confirm-body .time-summary .time-report .time-unit-group .time-value-float {
          width: 30px;
          overflow: auto;
          margin-right: 4px;
          float: left; }
          .modal-confirm-body .time-summary .time-report .time-unit-group .time-value-float .time-value {
            float: right;
            padding-right: 2px; }
        .modal-confirm-body .time-summary .time-report .time-unit-group .time-unit {
          font-size: 1.2rem; }

.modal-confirm-text {
  margin-bottom: 10px;
  font-size: 1.5rem; }

/* Fixed-location informational boxes */
.fixed-infobox-outer {
  margin: 20px auto;
  position: fixed;
  top: 160px;
  left: 0;
  right: 0;
  z-index: 1009; }

.fixed-infobox {
  display: block;
  text-align: center;
  width: 40%;
  margin: 0 auto;
  padding: 10px;
  border-radius: 5px; }

.save-message {
  display: inline-block;
  position: relative;
  left: 15px;
  color: white; }

.task-view {
  font-size: 1.5rem;
  position: relative; }
  .task-view .topbar-overview {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    font-size: 1.8rem;
    line-height: 2rem;
    background-color: #cccccc;
    box-shadow: 0 1px 3px #cccccc;
    color: #565656;
    height: 5rem; }
    .task-view .topbar-overview .topbar-leader {
      float: left;
      background-color: #565656;
      position: relative;
      color: white;
      z-index: 2; }
      .task-view .topbar-overview .topbar-leader .arrow-wrapper {
        position: absolute;
        right: -5rem; }
        .task-view .topbar-overview .topbar-leader .arrow-wrapper .arrow-with-shadow {
          width: 5rem;
          height: 5rem;
          position: relative;
          right: 0;
          overflow: hidden; }
        .task-view .topbar-overview .topbar-leader .arrow-wrapper .arrow-with-shadow:after {
          content: "";
          position: absolute;
          width: 3.53557rem;
          height: 3.53557rem;
          -webkit-transform: rotate(45deg);
          -ms-transform: rotate(45deg);
          -moz-transform: rotate(45deg);
          -o-transform: rotate(45deg);
          transform: rotate(45deg);
          top: 0.88389rem;
          left: -1.76778rem;
          box-shadow: 1px -1px 3px #bfbfbf;
          background-color: #565656; }
      .task-view .topbar-overview .topbar-leader .project-overview {
        padding: 1.5rem;
        margin-left: 3rem;
        background-color: #565656;
        float: left; }
        .task-view .topbar-overview .topbar-leader .project-overview .workflow {
          float: left;
          font-weight: bold;
          padding-right: 1.5rem; }
    .task-view .topbar-overview .topbar-follower {
      z-index: 1;
      padding-top: 1.5rem;
      padding-bottom: 1.5rem;
      float: left; }
      .task-view .topbar-overview .topbar-follower .task-overview {
        font-weight: bold;
        margin-left: 2.5rem;
        padding-left: 2.5rem; }
  .task-view .step-interface {
    margin-top: 8rem; }
  .task-view .reminders-title {
    padding: 10px 0;
    font-weight: bold; }
  .task-view .task-actions-wrapper {
    position: absolute;
    left: 0;
    right: 0;
    background-color: gray; }
    .task-view .task-actions-wrapper .task-actions {
      margin-left: 3rem;
      margin-right: 3rem;
      font-size: 1.3em; }
      .task-view .task-actions-wrapper .task-actions .btn {
        font-size: 1em; }
        .task-view .task-actions-wrapper .task-actions .btn:not(:first-child) {
          margin-left: 1.5rem; }
  .task-view .required-field-error.checkbox-error label {
    border-left: 2px solid red;
    overflow: auto;
    margin-bottom: 10px; }
  .task-view .required-field-error.text-error input {
    border: 1px solid red;
    box-shadow: 0px 0px 1px red inset; }
  .task-view .required-field-error.radio-error {
    border-left: 2px solid red;
    padding-left: 10px;
    display: inline-block; }
@charset "UTF-8";
/*!
 * Pikaday
 * Copyright © 2014 David Bushell | BSD & MIT license | https://dbushell.com/
 */
.pika-single {
  z-index: 9999;
  display: block;
  position: relative;
  color: #333;
  background: #fff;
  border: 1px solid #ccc;
  border-bottom-color: #bbb;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif; }
  .pika-single.is-hidden {
    display: none; }
  .pika-single.is-bound {
    position: absolute;
    box-shadow: 0 5px 15px -5px rgba(0, 0, 0, 0.5); }

.pika-single {
  *zoom: 1; }
  .pika-single:before, .pika-single:after {
    content: " ";
    display: table; }
  .pika-single:after {
    clear: both; }

.pika-lendar {
  float: left;
  width: 240px;
  margin: 8px; }

.pika-title {
  position: relative;
  text-align: center; }
  .pika-title select {
    cursor: pointer;
    position: absolute;
    z-index: 9998;
    margin: 0;
    left: 0;
    top: 5px;
    filter: alpha(opacity=0);
    opacity: 0; }

.pika-label {
  display: inline-block;
  *display: inline;
  position: relative;
  z-index: 9999;
  overflow: hidden;
  margin: 0;
  padding: 5px 3px;
  font-size: 14px;
  line-height: 20px;
  font-weight: bold;
  color: #333;
  background-color: #fff; }

.pika-prev,
.pika-next {
  display: block;
  cursor: pointer;
  position: relative;
  outline: none;
  border: 0;
  padding: 0;
  width: 20px;
  height: 30px;
  text-indent: 20px;
  white-space: nowrap;
  overflow: hidden;
  background-color: transparent;
  background-position: center center;
  background-repeat: no-repeat;
  background-size: 75% 75%;
  opacity: .5;
  *position: absolute;
  *top: 0; }
  .pika-prev:hover,
  .pika-next:hover {
    opacity: 1; }
  .pika-prev.is-disabled,
  .pika-next.is-disabled {
    cursor: default;
    opacity: .2; }

.pika-prev,
.is-rtl .pika-next {
  float: left;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAUklEQVR42u3VMQoAIBADQf8Pgj+OD9hG2CtONJB2ymQkKe0HbwAP0xucDiQWARITIDEBEnMgMQ8S8+AqBIl6kKgHiXqQqAeJepBo/z38J/U0uAHlaBkBl9I4GwAAAABJRU5ErkJggg==");
  *left: 0; }

.pika-next,
.is-rtl .pika-prev {
  float: right;
  background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAU0lEQVR42u3VOwoAMAgE0dwfAnNjU26bYkBCFGwfiL9VVWoO+BJ4Gf3gtsEKKoFBNTCoCAYVwaAiGNQGMUHMkjGbgjk2mIONuXo0nC8XnCf1JXgArVIZAQh5TKYAAAAASUVORK5CYII=");
  *right: 0; }

.pika-select {
  display: inline-block;
  *display: inline; }

.pika-table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0;
  border: 0; }
  .pika-table th,
  .pika-table td {
    width: 14.285714285714286%;
    padding: 0; }
  .pika-table th {
    color: #999;
    font-size: 12px;
    line-height: 25px;
    font-weight: bold;
    text-align: center; }
  .pika-table abbr {
    border-bottom: none;
    cursor: help; }

.pika-button {
  cursor: pointer;
  display: block;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  outline: none;
  border: 0;
  margin: 0;
  width: 100%;
  padding: 5px;
  color: #666;
  font-size: 12px;
  line-height: 15px;
  text-align: right;
  background: #f5f5f5; }
  .is-today .pika-button {
    color: #33aaff;
    font-weight: bold; }
  .is-selected .pika-button {
    color: #fff;
    font-weight: bold;
    background: #33aaff;
    box-shadow: inset 0 1px 3px #178fe5;
    border-radius: 3px; }
  .is-disabled .pika-button,
  .is-outside-current-month .pika-button {
    color: #999;
    opacity: .3; }
  .is-disabled .pika-button {
    pointer-events: none;
    cursor: default; }
  .pika-button:hover {
    color: #fff;
    background: #ff8000;
    box-shadow: none;
    border-radius: 3px; }
  .pika-button .is-selection-disabled {
    pointer-events: none;
    cursor: default; }

.pika-week {
  font-size: 11px;
  color: #999; }

.is-inrange .pika-button {
  background: #D5E9F7; }

.is-startrange .pika-button {
  color: #fff;
  background: #6CB31D;
  box-shadow: none;
  border-radius: 3px; }

.is-endrange .pika-button {
  color: #fff;
  background: #33aaff;
  box-shadow: none;
  border-radius: 3px; }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

.timecard-view {
  position: absolute;
  top: 100px;
  width: 80%;
  max-width: 750px;
  left: 50%;
  transform: translateX(-50%);
  font-size: 1.4rem; }
  .timecard-view .date-picker {
    cursor: pointer; }
    .timecard-view .date-picker i {
      margin-right: 3px;
      color: #0079bf; }
  .timecard-view .help-icon {
    font-size: 3rem; }
  .timecard-view .incomplete {
    color: red; }
  .timecard-view .edit-label {
    display: block;
    font-size: 0.8em;
    font-weight: bold;
    text-transform: uppercase;
    margin-right: 5px; }
  .timecard-view .timecard-header {
    padding: 1.5rem; }
  .timecard-view .edit-tools {
    float: left; }
    .timecard-view .edit-tools i {
      margin-right: 5px;
      cursor: pointer; }
      .timecard-view .edit-tools i.active {
        color: #0079bf; }
  .timecard-view .day-name {
    display: block;
    padding-right: 1.5rem;
    text-align: right;
    font-size: 1.8rem;
    font-weight: bold;
    text-transform: uppercase; }
  .timecard-view .date-group {
    position: relative;
    padding: 0.75rem;
    margin: 0.75rem 0; }
    .timecard-view .date-group h2 {
      position: relative;
      font-size: 1.8rem;
      padding: 1.5rem;
      border-bottom: 1px solid #cccccc;
      background-color: white; }
      .timecard-view .date-group h2 .date-label {
        color: #27ae60;
        text-transform: uppercase;
        margin-right: 5px; }
      .timecard-view .date-group h2 .btn-add-entry {
        cursor: pointer;
        position: relative; }
        .timecard-view .date-group h2 .btn-add-entry:hover::after {
          content: 'New entry';
          position: absolute;
          top: 50%;
          right: 0px;
          padding: 5px;
          transform: translate(100%, -50%);
          text-transform: uppercase;
          font-weight: bold;
          font-size: 0.6em;
          font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"; }
      .timecard-view .date-group h2 .date-duration {
        float: right;
        display: inline-block;
        vertical-align: bottom; }
  .timecard-view .entry-row {
    position: relative;
    background-color: white;
    box-sizing: border-box;
    padding: 1.5rem;
    background-color: white; }
    .timecard-view .entry-row.gray-stripe {
      background-color: rgba(204, 204, 204, 0.5); }
    .timecard-view .entry-row .row {
      padding: 5px 0; }
    .timecard-view .entry-row .description input {
      width: 100%; }
    .timecard-view .entry-row .edit-time {
      text-align: right; }
      .timecard-view .entry-row .edit-time label {
        margin: 0; }
      .timecard-view .entry-row .edit-time .time-component {
        display: inline-block;
        text-align: center; }
    .timecard-view .entry-row .edit-task {
      float: left;
      width: 300px; }
      .timecard-view .entry-row .edit-task .ui-select-bootstrap > .ui-select-choices {
        width: auto; }
    .timecard-view .entry-row .edit-options {
      float: right; }
      .timecard-view .entry-row .edit-options .edit-cancel-handle {
        cursor: pointer;
        display: inline-block; }
        .timecard-view .entry-row .edit-options .edit-cancel-handle:hover {
          text-decoration: underline; }
    .timecard-view .entry-row .form-cell:not(:last-of-type) {
      padding-right: 10px; }
    .timecard-view .entry-row:hover input:read-only, .timecard-view .entry-row.editing input:read-only {
      background: white; }
  .timecard-view .time-input {
    width: 55px; }
  .timecard-view .show-description {
    font-size: 1rem;
    color: #0079bf;
    cursor: pointer; }
/**
 * Common stylesheet for Orchestra.
 *
 * This partial provides common variables and mixins useful for various view and
 * component styles.
 */
.disable-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.row.no-padding, .row.no-padding > [class*="col-"] {
  padding-left: 0;
  padding-right: 0; }

@keyframes spin {
  from {
    transform: rotate(0deg); }
  to {
    transform: rotate(360deg); } }

.timer {
  font-size: 18px; }
  .timer .popover-toggle {
    line-height: 52px;
    cursor: pointer;
    color: white;
    font-size: 1.4em; }
  .timer .start-timer.btn {
    color: white;
    background-color: #2ecc71;
    display: inline-block; }
  .timer .time-display {
    font-size: 28px;
    line-height: initial;
    vertical-align: top;
    text-align: left;
    font-family: "Lucida Console", Monaco, monospace; }
  .timer .description input {
    width: 100%; }
  .timer .past-entries {
    margin-top: 10px;
    padding-top: 10px;
    border-top: 1px solid #cccccc; }
    .timer .past-entries h1 {
      font-size: 0.8em;
      margin-bottom: 10px; }
  .timer a {
    cursor: pointer; }
  .timer .popover {
    width: 300px;
    max-width: none; }
    .timer .popover .timer-popover {
      padding: 0; }
      .timer .popover .timer-popover .ui-select-bootstrap > .ui-select-choices {
        width: auto; }
      .timer .popover .timer-popover .row {
        margin: 10px 0; }
      .timer .popover .timer-popover .tgl + .tgl-btn {
        display: inline-block;
        margin-bottom: 0; }
    .timer .popover .tgl {
      display: none; }
      .timer .popover .tgl, .timer .popover .tgl:after, .timer .popover .tgl:before,
      .timer .popover .tgl *, .timer .popover .tgl *:after, .timer .popover .tgl *:before,
      .timer .popover .tgl + .tgl-btn {
        box-sizing: border-box; }
        .timer .popover .tgl::selection, .timer .popover .tgl:after::selection, .timer .popover .tgl:before::selection,
        .timer .popover .tgl *::selection, .timer .popover .tgl *:after::selection, .timer .popover .tgl *:before::selection,
        .timer .popover .tgl + .tgl-btn::selection {
          background: none; }
      .timer .popover .tgl + .tgl-btn {
        outline: 0;
        display: block;
        width: 4em;
        height: 2em;
        position: relative;
        cursor: pointer;
        user-select: none; }
        .timer .popover .tgl + .tgl-btn:after, .timer .popover .tgl + .tgl-btn:before {
          position: relative;
          display: block;
          content: "";
          width: 50%;
          height: 100%; }
        .timer .popover .tgl + .tgl-btn:after {
          left: 0; }
        .timer .popover .tgl + .tgl-btn:before {
          display: none; }
      .timer .popover .tgl:checked + .tgl-btn:after {
        left: 50%; }
    .timer .popover .tgl-ios + .tgl-btn {
      background: #fbfbfb;
      border-radius: 2em;
      padding: 2px;
      transition: all .4s ease;
      border: 1px solid #e8eae9; }
      .timer .popover .tgl-ios + .tgl-btn:after {
        border-radius: 2em;
        background: #fbfbfb;
        transition: left 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275), padding 0.3s ease, margin 0.3s ease;
        box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 4px 0 rgba(0, 0, 0, 0.08); }
      .timer .popover .tgl-ios + .tgl-btn:hover:after {
        will-change: padding; }
      .timer .popover .tgl-ios + .tgl-btn:active {
        box-shadow: inset 0 0 0 2em #e8eae9; }
        .timer .popover .tgl-ios + .tgl-btn:active:after {
          padding-right: .8em; }
    .timer .popover .tgl-ios:checked + .tgl-btn {
      background: #86d993; }
      .timer .popover .tgl-ios:checked + .tgl-btn:active {
        box-shadow: none; }
        .timer .popover .tgl-ios:checked + .tgl-btn:active:after {
          margin-left: -.8em; }
.time-input {
  color: black; }
.todo-list .section-body {
  padding-top: 1.5rem;
  padding-bottom: 1.5rem; }

.todo-list .todolist-pane {
  border: 1px solid black;
  padding: 1.5rem; }
  .todo-list .todolist-pane__heading {
    margin-top: -2.8rem;
    background-color: white;
    text-align: center; }

.todo-list .new-todo__datetime {
  display: inline-block;
  padding-left: 10px; }

.todo-list .new-todo select.form-control {
  border: 0;
  outline: 1px solid #cecece;
  outline-offset: -1px;
  box-shadow: none; }

.todo-list .new-todo .form-control, .todo-list .new-todo .button {
  border-radius: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: none; }
.todo--skipped {
  opacity: 0.5; }

.todo--disapproved {
  color: #a94442; }

.todo--approved {
  color: #3ab73a; }

.todo-qa-comment {
  display: block;
  font-size: xx-small;
  padding: 0px; }
.list-by-status {
  padding-top: 20px; }
  .list-by-status h4 {
    padding-bottom: 10px; }
  .list-by-status .todo {
    margin-left: 18px; }
    .list-by-status .todo input[type=checkbox] {
      transform: scale(1.1);
      margin-left: -22px; }
    .list-by-status .todo label {
      align-items: end;
      display: inline; }
    .list-by-status .todo__role {
      font-weight: 500;
      padding-left: 5px; }
    .list-by-status .todo__dates {
      padding-left: 5px;
      font-style: italic;
      color: #999; }
      .list-by-status .todo__dates-danger {
        color: #a94442; }
      .list-by-status .todo__dates-separator {
        font-style: normal; }
    .list-by-status .todo-qa {
      margin-bottom: 0; }
      .list-by-status .todo-qa .panel-body {
        padding: 5px;
        font-size: x-small;
        font-weight: normal; }
  .list-by-status .angular-ui-tree-node {
    padding-top: 12px;
    padding-bottom: 0; }
  .list-by-status .skipped-todos {
    margin-left: -18px; }
  .list-by-status .fa-circle-o {
    font-size: xx-small;
    vertical-align: middle;
    margin-left: -18px; }
  .list-by-status .angular-ui-tree-handle > label {
    cursor: pointer; }
.angular-ui-tree-empty, .angular-ui-tree-dropzone {
  border: 1px dashed #bbb;
  min-height: 100px;
  background-color: #e5e5e5;
  background-image: -webkit-linear-gradient(45deg, #fff 25%, transparent 25%, transparent 75%, #fff 75%, #fff), -webkit-linear-gradient(45deg, #fff 25%, transparent 25%, transparent 75%, #fff 75%, #fff);
  background-image: -moz-linear-gradient(45deg, #fff 25%, transparent 25%, transparent 75%, #fff 75%, #fff), -moz-linear-gradient(45deg, #fff 25%, transparent 25%, transparent 75%, #fff 75%, #fff);
  background-image: linear-gradient(45deg, #fff 25%, transparent 25%, transparent 75%, #fff 75%, #fff), linear-gradient(45deg, #fff 25%, transparent 25%, transparent 75%, #fff 75%, #fff);
  background-size: 60px 60px;
  background-position: 0 0, 30px 30px; }

.angular-ui-tree-empty {
  pointer-events: none; }

.angular-ui-tree-nodes {
  position: relative;
  margin: 0;
  padding: 0;
  list-style: none; }

.angular-ui-tree-nodes .angular-ui-tree-nodes {
  padding-left: 20px; }

.angular-ui-tree-node, .angular-ui-tree-placeholder {
  position: relative;
  margin: 0;
  padding: 0;
  min-height: 20px;
  line-height: 20px; }

.angular-ui-tree-hidden {
  display: none; }

.angular-ui-tree-placeholder {
  margin: 10px;
  padding: 0;
  min-height: 30px; }

.angular-ui-tree-handle {
  cursor: move;
  text-decoration: none;
  font-weight: bold;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
  min-height: 20px;
  line-height: 20px; }

.angular-ui-tree-drag {
  position: absolute;
  pointer-events: none;
  z-index: 999;
  opacity: .8; }

.angular-ui-tree-drag .tree-node-content {
  margin-top: 0; }
